{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<div class="fond-blanc">
 <input class="enorme" id="code" name="code" placeholder="{% translate '123456' %}"/>
 <div class="bien_visible" id="reponse">
 </div>
</div>
<audio id="xylo" src="{% static '/img/xylofon.wav' %}" style="display: none;">
</audio>
<audio id="percu" src="{% static '/img/percussion-50.wav' %}" style="display: none;">
</audio>
<audio id="alerte" src="{% static '/img/beau-danube.mp3' %}" style="display: none;">
</audio>
<script>
 revue_du_stock_init();
</script>
{% endblock %}

