{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<div class="python-code">
{% translate "########### données de corrélation extraites le" %} {{ date  }} {% translate "###############" %}
{% translate "# les options :" %}
options = {{ options }}
{% translate "# les abrégés :" %}
abreges = {{ abreges }}
{% translate "# données : liste de doublets (vecteur boolen des options), (vecteur booleen des abreges)" %}
donnees = {{ donnees }}
</div>
{% endblock %}

