{% extends "base.html" %}
{% block content %}
        {% for p in hidden_pages  if p.slug == "landing-page-about-hidden" %}
        <header>
            <h2>
                <a href="{{ SITEURL }}/index.html">{{ p.title }}</a>
            </h2>
            <p>
                <meta itemprop="datePublished" content="{{ p.date.isoformat() }}">
                <meta itemprop="dateModified" content="{{ p.date.isoformat() }}">
                {% if GRAVATAR_IMAGE %}
                <meta itemprop="image" content="{{ GRAVATAR_IMAGE }}">
                {% endif %}
            </p>
        </header>
        {{ p.content }}
	{% endfor %}
{% endblock %}
