{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<table style="display: inline-block; vertical-align: top;">
 <tr>
  <th colspan="2" style="background: white; border: 1px solid navy; padding: 5px;">
   {% translate "Sauvegarder la base de données" %}
  </th>
 </tr>
 <tr>
  <td style="text-align: center">
   <b>
    {% translate "Format Sqlite" %}
   </b>
   <br/>
   {% translate "(comprimé au format ZIP)" %}
   <br/>
   <button class="actionbuttons" onclick="waitDB('sqlite'); document.location='/saveDB?format=sqlite'">
    <img alt="Sauvegarde" src="{% static '/img/document-sqlite-save.svg' %}" style="float: left; height: 100px; margin 0 5px;"/>
   </button>
  </td>
 </tr>
</table>
<div style="display: inline-block; vertical-align: top;">
 <h3>
  {% translate "Liste des sauvegardes automatiques" %}
 </h3>
 <ol style="font-family: monospace;">
  {% for chemin, nom in sauvegardes %}
  <li>
   <a href="{{ chemin }}">
    {{ nom }}
   </a>
  </li>
  {% endfor %}
 </ol>
</div>
<div id="wait" style="display: none;" title="{% translate 'Patience ...' %}">
 <p>
  {% translate "Le fichier de sauvegarde est en cours d'exportation, cela peut
    durer quelques secondes." %}
 </p>
 <img alt="attente" src="{% static '/img/timer1.gif' %}"/>
</div>
{% endblock %}

