{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<form>
 {% csrf_token %}
 <fieldset style="border 1px black solid; padding: 5px; border-radius: 5px;">
  <legend>
   {% translate "Caution pour ..." %}
  </legend>
  <label for="nomprenom">
   {% translate "Élève :" %}
  </label>
  <input id="nomprenom" name="nomprenom" placeholder="{% translate 'NOM, Prénom' %}" type="text" value="{{ nomprenom }}" />
  <input val="{{ eleve.id }}" id="numero" name="numero" type="hidden" />
 </fieldset>
</form>
<div id="donnees">
 <div id="donnees-eleve" style="display:none;">
 </div>
 <div class="flexcontainer" id="boutons0">
  <div class="flexordinaire" id="cahier">
   <h3>
    {% translate "Le cahier des cautions" %}
   </h3>
   <button id="cahier-cautions" onclick="location = '/cahier_cautions'">
    <img alt="Cahier des cautions" src="{% static '/img/document-print.svg' %}" style="width: 100px;" title="{% translate 'Imprimer le cahier des cautions' %}"/>
   </button>
  </div>
  <div class="flexordinaire" id="par-classe" style="width: 700px;">
   <h3>
    {% translate "Vue, par classe" %}
   </h3>
   <form>
    <input id="classe" name="classe" placeholder="{% translate 'Quelle classe ?' %}" type="text"/>
   </form>
   <div id="cautions_classe">
   </div>
  </div>
 </div>
</div>
<div id="messages" style="display:none;">
</div>
<script>
 cautions_init();
</script>
{% endblock %}

