{% load i18n %}
{% load static %}
<tr>
 <td class="id_manuel">
  {{ manuel.id}}
 </td>
 <td class="title_manuel">
  {{ manuel.materiel.titre }}
 </td>
 <td>
  <select>
   {% for k, v in etat_materiel_choix.items %}
   <option %}="" %}selected{%="" endif="" if="" k="etat" value="{{ k }}" {%="">
    {{ v }}
   </option>
   {% endfor %}
  </select>
 </td>
 <td>
  <button onclick="deprete_livre(this)">
   <img alt="On ne prête plus ce manuel" src="{% static '/img/edit-delete.svg'  %}" style="width: 24px;"/>
  </button>
 </td>
</tr>

