{% load i18n %}
{% load static %}
<div style="margin-left: 60px;">
 <button id="go-to-prets" onclick="goto_prets('{{ nomprenom }}');" type="button">
   <img alt="rendu"
	src="{% static '/img/undo.svg' %}" style="width: 100px;"
	title="{% blocktranslate with e=nomprenom %}Prêter des livres à {{ e }}{% endblocktranslate %}"/>
 </button>
 {% if not sans_caution %}
 <button id="rend-caution" onclick="rend_caution('{{ sans_accent }}');" type="button">
   <img alt="rendre la caution"
	src="{% static '/img/caution-delete.svg' %}" style="width: 100px;"
	title="{% blocktranslate with e=nomprenom %}Rendre sa caution à {{ e }}{% endblocktranslate %}"/>
 </button>
 {% endif %}
</div>
{% include 'gestion/signale_eleve.html' %}
<h3>
 {{ classe }}{% translate ": liste des élèves" %}
</h3>
<div class="liste-scroll-y">
 <table>
  {% for e in eleves %}
  <tr onclick="montre_retours('{{ e.NomPrenomEleve|escapejs }}')">
      <td style="cursor:pointer; border-bottom: 1px blue dotted;"
	  {% if e.NomPrenomEleve == nomprenom %}
	  class = "meme-eleve"
	  {% endif %}
	  >
	{{ e.NomPrenomEleve }}
      </td>
      <td style="cursor:pointer; border-bottom: 1px blue dotted;"
	  {% if e.NomPrenomEleve == nomprenom %}
	  class = "meme-eleve"
	  {% endif %}
	  >
	({{ e.classes_passees }})
      </td>
  </tr>
  {% endfor %}
 </table>
</div>

