{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<input type="hidden" id="alerte-code"
       data-title="{% translate 'CE CODE DE LIVRE EST INCONNU' %}"
       value="{% translate 'Le code de livre {c} est inconnu du système ; veuillez entrer un autre code.' %}" />
{# les marquages {c} {m} {e} ci-dessous sont traités par slm.js #}
<input type="hidden" id="alerte-tiers"
       data-title="{% translate 'CE LIVRE EST À QUELQU&apos;UN D&apos;AUTRE' %}"
       value="{% translate 'Le livre de code {c}, « {m} » avait été prêté à {e}. Rendons-nous ce livre au nom de {f} ?' %}" />
<input type="hidden" id="alerte-nonprete"
       data-title="{% translate 'CE LIVRE N&apos;A PAS ÉTÉ PRÊTÉ' %}"
       value="{% translate 'Le livre de code {c}, « {m} » n&apos;est prêté à personne, selon les informations connues du système. Que fait-il ici ?' %}" />
<div id="all-contents">
 <div id="gestion-prets">
  <form>
   {% csrf_token %}
   <label for="nomprenom">
    {% translate "Élève :" %}
   </label>
   <input %}="" endif="" id="nomprenom" if="" name="nomprenom" nomprenom="" placeholder="{% translate 'NOM, Prénom' %}" type="text" value="{{ nomprenom }}" {%=""/>
   <button onclick="efface_nomprenom()" style="margin-right: 5px;" type="button">
    <img alt="RAZ nomprenom" src="{% static '/img/edit-delete.svg' %}" style="width: 16px;" title="{% translate 'Effacer le nom' %}"/>
   </button>
   <button onclick="que_prendre()" style="margin-right: 5px;" type="button">
    <img alt="livres à prendre" src="{% static '/img/aide.svg' %}" style="width: 16px;" title="{% translate 'Livres à prendre' %}"/>
   </button>
   <label for="codelivre">
    {% translate "Nouveau livre (entrer le code) :" %}
   </label>
   <input id="codelivre" name="codelivre" placeholder="{% translate '00000' %}" type="text"/>
   <input id="multiples" type="hidden" value="1"/>
  </form>
  <div class="fond-blanc" id="nouveaux_livres" style="display: inline-block;">
   <table class="nouveaux_livres">
    <caption>
     <div class="flexcaption">
      <button class="actionbuttons" onclick="prets_go()">
       <img alt="Enregistrer les nouveaux livres" src="{% static '/img/document-save.svg' %}" title="{% translate 'Enregistrer les nouveaux livres' %}"/>
      </button>
      <div style="margin-left: 5px; text-align: right;">
       <span id="caption0">
        {% translate "Nouveaux livres à prêter." %}
       </span>
       <br/>
       {% translate "Cliquer sur le bouton ci-contre" %}
       <br/>
       {% translate "pour les enregistrer." %}
      </div>
     </div>
    </caption>
    <tr>
     <th>
      {% translate "Code-barre" %}
     </th>
     <th>
      {% translate "Manuel à prêter" %}
     </th>
     <th>
      {% translate "État à considérer" %}
     </th>
     <th>
      {% translate "Ou pas ?" %}
     </th>
    </tr>
   </table>
  </div>
  <div id="tableau_prets">
  </div>
 </div>
 <div id="meme-classe" style="display: none">
 </div>
</div>
<audio id="soundicon1" src="{% static '/img/xylofon.wav' %}" style="display: none;">
</audio>
<audio id="soundicon2" src="{% static '/img/percussion-50.wav' %}" style="display: none;">
</audio>
<audio id="soundicon3" src="{% static '/img/beau-danube.mp3' %}" style="display: none;">
</audio>
<div id="invisible" style="display: none;">
 <!-- ce formulaire invisible permet de rendre un livre tiers -->
 <form action="/retours" id="livre_tiers" method="post" target="_blank">
  {% csrf_token %}
  <input id="nomprenom_cache" name="nomprenom" type="text">
   <input id="codelivre_cache" name="livre" type="text"/>
  </input>
 </form>
</div>
<div id="messages" style="display: none;">
</div>
<div class="notif" id="shortmessage" style="display: none;">
 {% translate "Le prêt de livres s'est bien déroulé ;" %}
 <br/>
 {% translate "pensez à imprimer la fiche de prêt." %}
</div>
<script>
 prets_init("{{ nomprenom }}");
</script>
{% endblock %}

