{% macro translations_for(article) %}
{% if article.translations %}
<div class="translation-header" onclick="deplieSommaire()">
≡ <br>
<span class="collapsible">
  {{ STATIC_TRANSLATIONS.Translations }}
  <div class="flags">
    {% for translation in article.translations %}
    {% if translation.lang != HIDE_LANG %}
    <a href="{{ SITEURL }}/{{ translation.url }}"
       hreflang="{{ translation.lang }}">
      <img alt="{{ translation.lang }}"
	   title="{{ translation.lang }}"
	   src="/aide/theme/img/flags/{{ translation.lang }}.svg"
	   style="width:50px;" />
    </a>
    {% endif %}
    {% endfor %}
    </div>
</span>
</div>
{% endif %}
{% endmacro %}

{% macro entry_hreflang(entry) %}
{% if entry.translations %}
  {% for translation in entry.translations %}
    <link rel="alternate" hreflang="{{ translation.lang }}" href="{{ SITEURL }}/{{ translation.url }}">
  {% endfor %}
{% endif %}
{% endmacro %}
