{% load i18n %}
<div class="paragraphe_tasse" style="margin-left: 60px;">
 {% if sans_caution %}
 <p>
  {% translate "Sans caution" %}
 </p>
 {% else %}
 <p>
  {% translate "Carte de membre (n°" %}
  <span id="no_caution">
   {{ no_caution }}
  </span>
  {% translate ")" %}
 </p>
 {% endif %}
 <p>
  {{ nomprenom }} {% translate "(" %}{{ classe }}{% translate ")" %}
 </p>
 {% if not sans_caution %}
  {% if besoin_carte %}
 <p class="warn">
  {% translate "reçoit sa carte cette année" %}
 </p>
 {% else %}
 <p>
  {% translate "a eu sa carte précédemment" %}
 </p>
 {% endif %}
  {% endif %}
 {% if caution_rendue %}
 <p class="warn">
  {% translate "La caution" %} {{ no_caution }} {% translate "a été rendue !" %}
 </p>
 {% endif %}
</div>

