{% load static %}
<div class="flag-container">
  {% for l, title in languages.items %}
  <div id="language-{{ l }}"
       class="lang{% if l == lang %} lang-chosen{% endif %}">
    <img src="/static/img/flags/{{ l }}.svg" alt="flag-{{ l }}"
	 style="width: 100%;vertical-align: middle;"
	 title="{{ title }}"
	 onclick="change_language('{{ l }}')"/>
  </div>
  {% endfor %}
</div>
