{% load i18n %}
{% load static %}

{% if valide %}
<!--
    conteneur pour les textes à traduire de la fonction JS casse_caution
  -->
<div id="cc" style="display: none;"
     data-impossible="{% translate 'impossible de rendre une caution de numéro zéro ! Définissez le numéro de caution, enregistrez et revenez.' %}"
     data-caution="{% translate 'Caution' %}"
     >
</div>
<form id="form-eleve" method="POST">
 {% csrf_token %}
 <input id="numero" name="numero" type="hidden" value="{{ numero }}"/>
 <input id="annee" name="annee" type="hidden" value="{{ annee }}"/>
 <input name="modif_db" type="hidden" value="{% translate 'Enregistrer' %}"/>
 <button class="petitbouton" id="modif_db" style="display:none;" type="submit">
  <img alt="enregistrer" src="{% static '/img/document-save.svg' %}" title="{% translate 'Enregistrer les modifications' %}"/>
 </button>
 <table class="deux-colonnes-formulaire" style="display: inline-block; vertical-align: top;">
  {{ form.as_table }}
  <tr>
   <td colspan="2" style="text-align: center;">
    <input style="width: 95%;" type="submit" value="{% translate 'Valider les données' %}"/>
   </td>
  </tr>
 </table>
 <div id="les-boutons" style="display: inline-block">
  {% include 'gestion/signale_eleve.html' %}
  <button id="fiche_suivi" onclick="imprime_fiche_suivi()" type="button">
   <img alt="imprime la fiche de suivi" src="{% static '/img/fiche-suivi-print.svg' %}" style="width: 100px;" title="{% translate 'Imprimer la fiche de suivi' %}"/>
  </button>
  <button id="print_carte_membre" onclick="imprime_une_carte_membre()" type="button">
    <img alt="imprime la carte de membre"
	 src="{% static '/img/carte-membre-print.svg' %}"
	 style="width: 100px;"
	 title="{% translate 'Imprimer la carte de membre' %}"/>
  </button>
  <br/>
  <button id="go-to-prets" onclick="goto_prets('{{ nomprenom }}');" type="button">
    <img alt="prêt" src="{% static '/img/redo.svg' %}" style="width: 100px;"
	 title="{% blocktranslate with e=nomprenom %}Prêter des livres à {{ e }}{% endblocktranslate %}"/>
  </button>
  <button id="go-to-retours" onclick="goto_retours('{{ nomprenom }}');" type="button">
    <img alt="rendu" src="{% static '/img/undo.svg' %}" style="width: 100px;"
	 title="{% blocktranslate with e=nomprenom %}Rendre des livres de {{ e }}{% endblocktranslate %}"/>
  </button>
  <br/>
  {% if sans_caution %}
  <p>
   {% translate "S.C." %}
  </p>
  {% else %}
  <fieldset id="rendre-caution" style="border: 1px black solid; padding: 5px; border-radius: 5px;">
   <legend>
    {% translate "Rendre la caution" %}
   </legend>
   <input id="montant" style="width: 50px;" value="70,00"/>
   {% translate " €" %}
   <button id="casse-caution" onclick="casse_caution('{{ nomprenom }}');" type="button">
     <img alt="fin de la caution"
	  src="{% static '/img/caution-delete.svg' %}"
	  style="width: 50px; vertical-align: middle;"
	  title="{% blocktranslate with e=nomprenom %}Terminer (rendre) la caution de {{ e }}{% endblocktranslate %}"/>
   </button>
  </fieldset>
  {% endif %}
  <div id="confirme-caution" style="display: none;">
   <p>
    {% translate "Voulez-vous vraiment solder la caution de" %} {{ nomprenom }}{% translate " ?" %}
   </p>
  </div>
 </div>
</form>
<!-- formulaire invisible pour faire imprimer les fiches -->
<form action="fiches_suivi_print_go" id="go" method="post" style="display: none;">
 {% csrf_token %}
 <input )="" id="classes_input" name="classes" type="text" value=""/>
 <input id="annee" name="annee" type="text" value="{{ param.AnneeScolaire }}">
 </input>
</form>
{% else %}
<h3>
 {% translate "Le champ « Élève » n'a pas permis de trouver une fiche dans la base de données" %}
</h3>
{% endif %}
<script src="{% static 'js/jquery/jquery.js' %}">
</script>
<script src="{% static 'js/jquery-ui/jquery-ui.js' %}">
</script>
<script src="{% static 'js/slm.js' %}">
</script>
<script>
 eleve_modif_init()
</script>
{% if saved %}
<script>
 signale_eleve_saved()
</script>
{% endif %}

