{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Livres supplémentaires à emprunter, par un groupe d'élèves" %}
</h1>
<a href="{{ url }}">
 {% translate "Limite de validité de ce Qr-Code :" %} {{ jeton.perime }}
</a>
<br style="margin: 0 0 20px;"/>
{{ qrcode|safe }}
<div class="no-print" style="display: inline-block; vertical-align: top;">
 <img onclick="print()" src='{% static "/img/document-print.svg" %}' style="margin: 0 0 0 50px; cursor: pointer; vertical-align: top;"/>
 <br/>
 {% translate "imprimer ce QR-code" %}
 <br/>
 {% translate "d'invitation" %}
</div>
{% if livres_supplement %}
<div>
 <h3>
  {% translate "Demandes de livres à valider" %}
 </h3>
 <ul>
  {% for ls in livres_supplement %}
  <li>
   <button data-id="{{ ls.id }}" onclick="valide_livre_supplement(this)">
    {{ ls }}
   </button>
  </li>
  {% endfor %}
 </ul>
</div>
<div id="message" style="display: none; width: 450px; height: 400px;">
 <h3>
  {% translate "Demande de" %}
  <span class="prof">
   {% translate "prof" %}
  </span>
 </h3>
 <textarea class="comment" cols="40" rows="3"></textarea>
 <dl>
  <dt style="font-weight: bold;">
   {% translate "Livres" %}
  </dt>
  <dd class="livres" data-liste="[]">
  </dd>
  <dt style="font-weight: bold;">
   {% translate "Élèves" %}
  </dt>
  <dd class="eleves" data-liste="[]">
  </dd>
 </dl>
</div>
{% endif %}
{% endblock %}

