{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>{% translate "Actions sur des listes d'élèves à choisir" %}</h1>
<div id="outils-choix">
  <fieldset class="frame">
    <legend class="strong">{% translate "Outils de choix" %}</legend>
    <label for="nomprenom">
      {% translate "Un par un :" %}
    </label>
    <input %}="" endif="" id="nomprenom" if="" name="nomprenom" nomprenom="" placeholder="{% translate 'NOM, Prénom' %}" type="text" value="{{ nomprenom }}" {%=""/>
    
  </fieldset>
</div>
<div id="choix">
  <fieldset class="frame">
    <legend class="strong">{% translate "Liste d'élèves" %}</legend>
    <table class="tableau_prets">
      <tr><th>NOM Prénom</th><th>Suppr.</th></tr>
    </table>
  </fieldset>
</div>
<div id="actions">
  <fieldset class="frame">
    <legend class="strong">{% translate "Actions" %}</legend>
    <button onclick="action_courrier()">
      <img alt="Préparer des courriers"
	   src="{% static '/img/lettre.svg' %}"
	   title="{% translate 'Préparer des courriers' %}"
	   style="height: 50px;"/>
    </button>
  </fieldset>
</div>

<script>
  choix_eleves_init();
</script>
{% endblock %}

