{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Impression de codes-barres pour « " %}{{ manuel.titre }}{% translate " » (ISBN :" %} {{ manuel.ISBN }}{% translate ")" %}
</h1>
<input id="id_catalogue" type="hidden" value="{{ manuel.id }}"/>
<input id="date" type="hidden" value="{{ date|date:'Y-m-d' }}"/>
<input id="positions_tabou" type="hidden" value="{{ tabou }}"/>
<button id="inventaire" onclick="location ='/catalogue'" style="margin:5px 0;">
 {% translate "⏮ Retour à l'Inventaire/Catalogue" %}
</button>
<br/>
<button class="actionbuttons" id="redoButton" onclick="codes_barres_print_init(this)">
 <img alt="Mettre à jour la prévisualisation" src="{% static '/img/document-print-preview.svg' %}" title="{% translate 'Mettre à jour la prévisualisation' %}"/>
</button>
<button class="actionbuttons" id="resetButton" onclick="codes_barres_print_init(this)">
 <img alt="Revenir à la page initiale" src="{% static '/img/stock_undelete.svg' %}" title="{% translate 'Revenir à la page initiale' %}"/>
</button>
<button class="actionbuttons" id="printButton" onclick="codes_barres_print_go()">
 <img alt="Créer le fichier PDF" src="{% static '/img/document-print.svg' %}" title="{% translate 'Créer le fichier PDF' %}"/>
</button>
<div id="preview">
 <img alt="attendre..." src="{% static '/img/timer1.gif' %}"/>
</div>
<script>
 codes_barres_print_init();
</script>
{% endblock %}

