{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<div class="actionbuttons">
 <button onclick="document.location='/catalogue_print'">
  <img alt="Imprimer le catalogue" src="{% static '/img/document-print.svg' %}" title="{% translate 'Imprime le catalogue' %}"/>
 </button>
 <button onclick="newCatalogue({{ c.pk }})">
  <img alt="nouveau" src="{% static '/img/edit-add.svg' %}" title="{% translate 'Crée un nouvel enregistrement à partir de zéro' %}"/>
 </button>
</div>
<table class="tableau-donnees" id="tab-catalogue">
 <tr>
  <th>
   {% translate "Action" %}
  </th>
  <th>
   {% translate "Abrégé" %}
  </th>
  <th>
   {% translate "Titre/Éditeur" %}
  </th>
  <th>
   {% translate "Pour ..." %}
  </th>
  <th title="{% translate 'Tronc Commun' %}">
   {% translate "T.C." %}
  </th>
  <th>
   {% translate "Option/Spé" %}
  </th>
  <th>
   {% translate "Année" %}
  </th>
  <th>
   {% translate "code ISBN" %}
  </th>
  <th>
   {% translate "Prêtés /" %}
   <br/>
   {% translate "Étiquetés" %}
  </th>
  <th>
   {% translate "Prix" %}
  </th>
 </tr>
 {% for m in manuels %}
 <tr>
  <td>
   <button onclick="delCatalogue({{ m.pk }})">
    <img alt="supprimer" src="{% static '/img/edit-delete.svg' %}" title="{% translate 'Supprime l&apos;enregistrement' %}"/>
   </button>
   <button onclick="editCatalogue({{ m.pk }})">
    <img alt="éditer" src="{% static '/img/gtk-edit.svg' %}" title="{% translate 'Édite et Modifie cet enregistrement' %}"/>
   </button>
   <button onclick="code_barre({{ m.pk }})">
    <img alt="code-barre" src="{% static '/img/etiquette-mini.png' %}" title="{% translate 'Crée des codes-barres pour ce manuel' %}"/>
   </button>
   <button onclick="cloneCatalogue({{ m.pk }})">
    <img alt="cloner" src="{% static '/img/edit-add.svg' %}" title="{% translate 'Crée puis édite un clone de l&apos;enregistrement' %}"/>
   </button>
  </td>
  <td>
   {{ m.abrege_html | safe }}
  </td>
  <td>
   {{ m.titre }} {% translate "/" %} {{ m.editeur }}
  </td>
  <td>
   {% for s in m.split_categories %}
      {{ s }}
   <br/>
   {% endfor %}
  </td>
  <td style="font-weight: bold; font-size: 200%;">
   {% if m.tronc %}
      {% translate "☑" %}
      {% else %}
      {% translate "☐" %}
      {% endif %}
  </td>
  <td>
   {{ m.split_option|safe }}
  </td>
  <td>
   {{ m.Annee_Depot_Legal }}
  </td>
  <td>
   {{ m.ISBN }}
  </td>
  <td>
   {% if m.Achetes %}
      {{ m.Pretes }} {% translate "/" %} {{ m.Achetes }}
      {% else %}
      {% translate "Pas de manuel" %}
   <br/>
   {% translate "étiqueté pour" %}
   <br/>
   {% translate "le moment." %}
   <br/>
   {% translate "Cliquez sur le" %}
   <br/>
   {% translate "bouton pour" %}
   <br/>
   {% translate "générer les" %}
   <br/>
   {% translate "codes-barres." %}
   <br/>
   {% endif %}
  </td>
  <td>
   {{ m.Prix|floatformat:2}}{% translate " €" %}
  </td>
 </tr>
 {% endfor %}
</table>
<div id="dialog" style="display: none;">
 {% translate "Êtes-vous sûr de vouloir effacer cet enregistrement ?" %}
</div>
{% endblock %}

