{% load i18n %}
{% load static %}

{% if eleves %}
<h3>
 {% translate "Liste d'élèves en" %} {{ classe }}
</h3>
<p>
 {% translate "Cliquer sur un nom pour voir sa fiche" %}
</p>
<div class="liste-eleves">
 <ol>
  {% for e in eleves %}
  <li onclick="choixEleve(this)"
      title="{% blocktranslate with e=e.NomPrenomEleve %}Examiner la fiche de {{ e }}{% endblocktranslate %}">
   {{ e.NomPrenomEleve }}
  </li>
  {% endfor %}
 </ol>
</div>
{% else %}
<h3>
 {% translate "Le champ « Classe » n'identifie pas une classe connue" %}
</h3>
{% endif %}

