.author {
    padding: .5rem .5rem .5rem 0;
    margin: .5rem 0;
}

.author .photo {
    width: 1.8rem;
    height: 1.8rem;
    vertical-align: middle;
}

.author .name {
    font-size: 1rem;
    display: inline-block;
}

.author img {
    display: inline-block;
}
