{% load static %}
{% load i18n %}
<table class="tableau_prets">
 <caption>
  <div class="flexcaption">
   <button class="actionbuttons" onclick="prets_mkPDF()">
    <img alt="Créer la fiche de prêt" src="{% static '/img/document-print.svg' %}" title="{% translate 'Créer la fiche de prêt au format PDF' %}"/>
   </button>
   {% if not date_unique %}
   <div class="flex-vertical">
    <button class="actionbuttons" onclick="avenant_mkPDF(1)">
      <img alt="Ajouter un avenant (1)"
	   src="{% static '/img/document-print1.png' %}"
	   title="{% blocktranslate with l=nouveaux_prets d=date_prets %}Ajouter un premier avenant pour {{ l }} livre(s) prêtés le {{ d }}{% endblocktranslate %}"/>
    </button>
    <button class="actionbuttons" onclick="avenant_mkPDF(2)">
      <img alt="Ajouter un avenant (2)"
	   src="{% static '/img/document-print2.png' %}"
	   title="{% blocktranslate with l=nouveaux_prets d=date_prets%}Ajouter un deuxième avenant pour {{ l }} livre(s) prêté(s) le {{ d }}{% endblocktranslate %}"/>
    </button>
   </div>
   {% endif %}
   <div style="max-width: 400px;">
    {% if les_prets|length == 0 %}
	{% translate "Pas de prêts enregistrés pour" %}
    <br/>
    {% else %}
	{% if les_prets|length == 1 %}
	{% translate "1 prêt enregistré, pour" %}
    <br/>
    {% else %}
	{{les_prets|length}} {% translate "prêts enregistrés, pour" %}
    <br/>
    {% endif %}
	{% endif %}
    <!--
	{{eleve.NomPrenomEleve}}
	({{eleve.classe.libelle}})<br>
	  -->
    {% include 'gestion/signale_eleve.html' %}
    <span style="font-size: 80%; color: #555;font-style: italic; ">
     {% translate "Options :" %} {{ eleve.options }}
    </span>
   </div>
  </div>
 </caption>
 <tr>
  <th>
   {% translate "Titre" %}
  </th>
  <th>
   {% translate "Niveau" %}
  </th>
  <th>
   {% translate "Éditeur" %}
  </th>
  <th>
   {% translate "Année" %}
  </th>
  <th>
   {% translate "État" %}
  </th>
  <th>
   {% translate "Code-barre" %}
  </th>
 </tr>
 {% for p in les_prets %}
 <tr>
  <td class="title_manuel">
   {{ p.inventaire.materiel.titre }}
  </td>
  <td>
   {{ p.inventaire.materiel.niveau.abrege }}
  </td>
  <td>
   {{ p.inventaire.materiel.editeur }}
  </td>
  <td>
   {{ p.inventaire.materiel.Annee_Depot_Legal }}
  </td>
  <td>
   {{ p.inventaire.etat}}
  </td>
  <td class="id_manuel">
   {{ p.inventaire.id }}
  </td>
 </tr>
 {% endfor %}
</table>

