{% extends 'gestion/base_minimale.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Votre demande est enregistrée" %}
</h1>
<p>
 {% translate "Retour au site" %}
 <a href="{{ baseUrl }}">
  {{ baseUrl }}
 </a>
</p>
<table class="tableau_prets deux-colonnes-formulaire">
 <tr>
  <th>
   <label for="nomprenom">
    {% translate "Qui demande :" %}
   </label>
  </th>
  <td>
   {{ data.prof }}
  </td>
 </tr>
 <tr id="les-livres">
  <td colspan="2">
   <h3>
    {% translate "Livre(s) à prêter" %}
   </h3>
   <ul>
    {% for l in livres %}
    <li>
     {{ l }}
    </li>
    {% endfor %}
   </ul>
  </td>
 </tr>
 <tr id="les-eleves">
  <td colspan="2">
   <h3>
    {% translate "Pour ces élèves ..." %}
   </h3>
   <ul>
    {% for e in eleves %}
    <li>
     {{ e.NomPrenomEleve }} {% translate "(" %}{{ e.Lib_Structure }}{% translate ")" %}
    </li>
    {% endfor %}
   </ul>
  </td>
 </tr>
</table>
<p>
 {% translate "N.B. : Merci de poster un message, par exemple via" %}
 <a href="https://pronote.lyceejeanbart.fr" target="other">
  {% translate "Pronote" %}
 </a>
 {% translate ", à un bénévole de la Coopérative pour attirer son attention, après avoir validé le livre et la liste d'élèves." %}
</p>
{% endblock %}

