<header class="site-header">
    <a href="{{ SITEURL }}">
        {% if SITELOGO %}
        <img src="{{ SITELOGO }}" alt="{{ SITETITLE }}" title="{{ SITETITLE }}">
        {% else %}
        {% endif %}
    </a>
    <h1 itemprop="name"><a href="{{ SITEURL }}/index.html">{{ SITETITLE }}</a></h1>
    {% if SITESUBTITLE %}<p>{{ SITESUBTITLE }}</p>{% endif %}
    <nav class="menu">
      <ul>
    {% for p in pages %}
    <li>
      <a {% if p == page %} class="active"
	 {% else %} href="../../{{ p.url }}"
	 {% endif %}>
	{{ p.title }}
      </a>
    </li>
    {% endfor %}
    </ul>
    </nav>
</header>
