body {
    font-size: 12px;
}

.livre .container, #choix-boutique-ok .container {
    width: 120px;
    height: 50px;
    padding: 3px;
}

.qr-reader.ok, .qr-reader .ok{
    background: green;
    text-align: center;
    font-size: 20px;
}
.qr-reader.ko, .qr-reader .ko{
    background: red;
    text-align: center;
    font-size: 20px;
}
.qr-reader.kk, .qr-reader .kk{
    background: yellow;
    text-align: center;
    font-size: 20px;
}
.qr-reader button {
    vertical-align: middle;
    font-size: 20px;
    margin: 0 10px;
    cursor: pointer;
}

ul#coches {
    line-height: 10px;
}

#coches input{
    height: 10px;
    width: 10px;
}

#coches li {
    padding: 0;
    margin: 1px;
    border-radius: 2px;
}
