{% extends 'gestion/base_minimale.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
{% if jeton %}
<h1>
 {% translate "Le jeton est périmé, la session est finie" %}
</h1>
{% translate "La fin de validité du jeton était :" %} {{ jeton.perime }}
{% else %}
<h1>
 {% translate "Cette page n'est pas accessible dans les conditions courantes" %}
</h1>
<p>
 {% translate "Il faut passer à la Coopérative et demander une autorisation
  pour permettre l'accès à cette page." %}
</p>
{% endif %}
{% endblock %}

