{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<input type="hidden" id="alerte-code"
       data-title="{% translate 'CE CODE DE LIVRE EST INCONNU' %}"
       value="{% translate 'Le code de livre {c} est inconnu du système ; veuillez entrer un autre code.' %}" />
{# les marquages {c} {m} {e} ci-dessous sont traités par slm.js #}
<input type="hidden" id="alerte-tiers"
       data-title="{% translate 'CE LIVRE EST À QUELQU&apos;UN D&apos;AUTRE' %}"
       value="{% translate 'Le livre de code {c}, « {m} » avait été prêté à {e}. Rendons-nous ce livre au nom de {e} ?' %}" />
<input type="hidden" id="alerte-nonprete"
       data-title="{% translate 'CE LIVRE N&apos;A PAS ÉTÉ PRÊTÉ' %}"
       value="{% translate 'Le livre de code {c}, « {m} » n&apos;est prêté à personne, selon les informations connues du système. Que fait-il ici ?' %}" />
<div id="all-contents">
 <div id="gestion-retours">
  <form>
   {% csrf_token %}
   <label for="nomprenom">
    {% translate "Élève :" %}
   </label>
   <input %}="" endif="" id="nomprenom" if="" name="nomprenom" nomprenom="" placeholder="{% translate 'NOM, Prénom' %}" type="text" value="{{ nomprenom }}" {%=""/>
   <button onclick="efface_nomprenom()" style="margin-right: 5px;" type="button">
    <img alt="RAZ nomprenom" src="{% static '/img/edit-delete.svg' %}" style="width: 16px;" title="{% translate 'Effacer le nom' %}"/>
   </button>
   <label for="codelivre">
    {% translate "Livre rendu (entrer le code) :" %}
   </label>
   <input id="codelivre" name="codelivre" placeholder="{% translate '00000' %}" type="text"/>
  </form>
  <div id="impressions" style="display: none">
   <button onclick="imprime_restitution()">
    <img alt="fiche de restitution" src="{% static '/img/print-retour.png' %}" title="{% translate 'fiche de restitution' %}"/>
   </button>
   <button onclick="imprime_memoire()">
    <img alt="mémoire de perte" src="{% static '/img/print-memoire.png' %}" title="{% translate 'mémoire de perte' %}"/>
   </button>
  </div>
  <div class="fond-blanc" id="livres-rendus" style="display: inline-block;">
   <table class="livres_rendus">
    <tr class="titres">
     <th class="id_manuel">
      {% translate "N°" %}
     </th>
     <th class="disc">
      {% translate "Matière" %}
     </th>
     <th class="title_manuel">
      {% translate "Titre" %}
     </th>
     <th class="date-pret">
      {% translate "Prêté le" %}
     </th>
     <th class="date-retour">
      {% translate "Rendu le" %}
     </th>
     <th class="etat-initial">
      {% translate "État intitial" %}
     </th>
     <th class="etat-final">
      {% translate "État final" %}
     </th>
     <th class="degradation">
      {% translate "Dégradation" %}
     </th>
     <th class="perdu">
      {% translate "Perdu" %}
     </th>
     <th class="remise">
      {% translate "Remise" %}
     </th>
     <th class="paiement-perte">
      {% translate "Paiement perte" %}
     </th>
    </tr>
   </table>
  </div>
  <div id="tableau_prets">
  </div>
  <div id="messages" style="display: none;">
  </div>
 </div>
 <div id="meme-classe" style="display: none">
 </div>
</div>
<div class="notif" id="shortmessage" style="display: none;">
 {% translate "Le retour des livres s'est bien déroulé ;" %}
 <br/>
 {% translate "pensez à imprimer la fiche de rendu." %}
</div>
<audio id="soundicon1" src="{% static '/img/xylofon.wav' %}" style="display: none;">
</audio>
<audio id="soundicon2" src="{% static '/img/percussion-50.wav' %}" style="display: none;">
</audio>
<div id="invisible" style="display: none;">
 <!-- ce formulaire invisible permet de rendre un livre tiers -->
 <form action="/retours" id="livre_tiers" method="post" target="_blank">
  {% csrf_token %}
  <input id="nomprenom_cache" name="nomprenom" type="text"/>
  <input id="codelivre_cache" name="livre" type="text"/>
 </form>
</div>
<script>
 {% if livre %}
  retours_init("{{ nomprenom }}", "{{ livre }}");
  {% else %}
  retours_init("{{ nomprenom }}");
  {% endif %}
</script>
{% endblock %}

