{% load i18n %}
{% load static %}
<div class="bouton-classe" data-classe="{{ classe.libelle }}" onclick="plus_classe_supplement_go(this)" title="{% translate 'ajouter la classe' %}">
 <img alt="ajouter la classe" src="{% static '/img/edit-add.svg' %}" style="vertical-align: middle;" title="{% translate 'ajouter la classe' %}"/>
 {{ classe.libelle }}
</div>

