{% extends 'gestion/base.html' %}
{% load i18n %}


{% block contents %}
<div class="flexcontainer">
 <div class="flexcontained">
  <a class="title" href="/aide/{{ locale }}/index.html">
   {% translate "Aide" %}
  </a>
  <ul>
   <li>
    {% translate "Manuel de l'utilisateur de SML" %}
   </li>
   <li>
    {% translate "Manuel de l'administrateur (super-utilisateur)" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="/sauvegarde">
   {% translate "Sauvegarde" %}
  </a>
  <ul>
   <li>
    {% translate "Sauvegarde la base de données" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="/admin">
   {% translate "Maintenance" %}
  </a>
  <ul>
   <li>
    {% translate "Passer en mode maintenance." %}
	{% if not user.is_superuser %}
    <br/>
    {% translate "Il faut être super-utlisateur pour la maintenance ...
	mais l'utilisateur" %} {{ user.username }} {% translate "n'est pas super-utlisateur." %}
	{% endif %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="/importeFromGemaSCO">
   {% translate "importation GemaSCO" %}
  </a>
  <ul>
   <li>
    {% translate "Importer des tables de la base Gemasco : passer par des formats XLSX puis CSV (UTF-8)" %}
	{% if not user.is_superuser %}
    <br/>
    {% translate "Il faut être super-utlisateur pour cette importation ...
	mais l'utilisateur" %} {{ user.username }} {% translate "n'est pas super-utlisateur." %}
	{% endif %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="/correlation">
   {% translate "Corrélations" %}
  </a>
  <ul>
   <li>
    {% translate 'Corrélations constatées entre les "options" de SIÈCLE et les livres empruntés par les élèves' %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="/stats">
   {% translate "Statistiques" %}
  </a>
  <ul>
   <li>
    {% translate "Classes ..." %}
   </li>
   <li>
    {% translate "Prêts ..." %}
   </li>
   <li>
    {% translate "Livres : nombre, volume, masse ..." %}
   </li>
  </ul>
 </div>
</div>
{% endblock %}

