{% load i18n %}
{% load static %}
{% include 'gestion/signale_eleve.html' %}
<div style="margin-left: 60px;">
 <button onclick="imprime_une_carte_membre()">
   <img alt="imprime la carte de membre"
	src="{% static '/img/carte-membre-print.svg' %}"
	style="width: 100px;"
	title="{% blocktranslate with e=nomprenom %}Imprimer la carte de membre pour {{ e }}{% endblocktranslate %}"/>
 </button>
 <button id="go-to-retours" onclick="goto_retours('{{ nomprenom }}');" type="button">
   <img alt="rendu" src="{% static '/img/undo.svg' %}"
	style="width: 100px;"
	title="{% blocktranslate with e=nomprenom %}Rendre des livres de {{ e }}{% endblocktranslate %}"/>
 </button>
</div>
<h3>
  <button onclick="livres_de_classe('{{ classe }}')">
    <img alt="rendulivres" src="{% static '/img/office.svg' %}"
	style="width: 16px;"
	title="{% translate 'Livres à prévoir pour la classe' %}"/>
  </button>
  {{ classe }}{% translate ": liste des élèves" %}
</h3>
<div class="liste-scroll-y">
 <table>
  {% for e in eleves %}
  <tr onclick="montre_prets('{{ e.NomPrenomEleve|escapejs }}')">
      <td style="cursor:pointer; border-bottom: 1px blue dotted;"
	  {% if e.NomPrenomEleve == nomprenom %}
	  class = "meme-eleve"
	  {% endif %}
	  >
	{{ e.NomPrenomEleve }}
      </td>
      <td style="cursor:pointer; border-bottom: 1px blue dotted;"
	  {% if e.NomPrenomEleve == nomprenom %}
	  class = "meme-eleve"
	  {% endif %}
	  >
	({{ e.classes_passees }})
      </td>
  </tr>
  {% endfor %}
 </table>
</div>

