{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1 id="title">
 {{ manuel.titre }}
</h1>
<h2 id="isbn">
 {% translate "ISBN :" %} {{ manuel.ISBN }}
</h2>
<form action="/codes_barres_print" id="new" method="post">
 {% csrf_token %}
 <button class="actionbuttons" style="vertical-align :middle" title="{% translate 'Créer les entrées dans l&apos;inventaire et les codes-barres' %}" type="button">
  <img src="{% static '/img/etiquette-new.png' %}"/>
 </button>
 <input name="id_catalogue" type="hidden" value="{{ manuel.id }}"/>
 <div style="display:inline-block; vertical-align :middle">
  {% translate "Nouveaux manuels dans l'inventaire" %}
  <br/>
  <input id="nombre" name="nombre" style="width: 60px;" value="10"/>
  <select name="etat">
   {% for i,e in etats.items %}
   <option value="{{ i }}">
    {{ e }}
   </option>
   {% endfor %}
  </select>
 </div>
</form>
{% for item in manuels_inventories %}
<form action="/codes_barres_print" id="{{ item.Date_Achat_Materiel }}" method="post">
 {% csrf_token %}
 <button class="actionbuttons" style="vertical-align :middle"
	 title="{% blocktranslate with d=item.Date_Achat_Materiel %} 'Retrouver des codes-barres du {{ d }}{% endblocktranslate %}"
	 type="submit">
  <img src="{% static '/img/etiquette-mini.png' %}"/>
 </button>
 <input name="id_catalogue" type="hidden" value="{{ manuel.id }}"/>
 <div style="display:inline-block; vertical-align: middle">
  <input id="dejavu-{{ item.Date_Achat_Materiel }}" name="dejavu-{{ item.Date_Achat_Materiel }}" type="hidden" value="{{ item.Date_Achat_Materiel|date:'Y-m-d'}}"/>
  {% translate "Revoir" %}
  <b>
   {{ item.id__count }} {% translate "étiquettes" %}
  </b>
  <br>
   {% translate "créées le" %}
   <b>
    {{ item.Date_Achat_Materiel }}
   </b>
   {% translate "." %}
  </br>
 </div>
</form>
{% endfor %}
<div id="dialog" style="display:none" title="{% translate 'Veuillez confirmer' %}">
 <p>
  {% translate "Je veux en effet créer ?? nouvelles entrées d'inventaire pour
    ????." %}
 </p>
</div>
<script>
 codes_barres_init();
</script>
{% endblock %}

