{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<div class="fond-blanc" style="background: #F9DEEF;">
  {{ themethod }}
  {% if saisie %}
  {% if code_valide %}
  <form method="POST" id="form-eleve" action="/inscription_provisoire">
    {% csrf_token %}
    <input type="hidden" name="code_temporaire" value="{{ code_temporaire }}"/>
    <button type="submit" id="modif_db" class="petitbouton">
      <img src="{% static '/img/document-save.svg' %}" alt="enregistrer" title="{% translate 'Enregistrer les modifications' %}"/>
    </button>
    <table class="deux-colonnes-formulaire"
	   style="display: inline-block; vertical-align: top;">
      {{ form.as_table }}
      <tr><td colspan="2" style="text-align: center;"><input type="submit" value="{% translate 'Valider les données' %}" style="width: 95%;"/></td></tr>
    </table>
  </form>
  {% else %}  {# le code n'est plus valide #}
  <p>
    {% translate "
    Désolé, le code temporaire qui autorisait une inscription provisoire
    n'est plus valide (sa durée de validité était de 30 minutes).
    Contactez s'il vous plaît un responsable de la coopérative pour qu'il
    vous autorise à nouveau à faire l'inscription provisoire." %}
  </p>
  {% endif %} {# fin de if code_valide #}
  {% else %}
  <h1>{% translate "Merci pour le remplissage du formulaire d'inscription temporaire" %}</h1>
  <p>
    {% blocktranslate with n=eleve.NomPrenom %}
    Les données de {{ n }} sont enregistrées,
    elles devront être confirmées. S'il vous plaît, signalez à un
    responsable de la coopérative scolaire que vous avez fini cette
    inscription, et qu'on peut passer à la validation.
    {% endblocktranslate %}
  </p>
  <p>
    {% translate "En cas d'hésitation, le lien temporaire d'inscription reste valide, vous pouvez encore rectifier quelques données en" %}
    <a href="/inscription_provisoire?code_temporaire={{ code_temporaire }}">
      {% translate "Cliquant ici" %}
    </a>
  </p>
  {% endif %}
</div>
<script>
  $("#page_header a").attr("href", "#"); /* désactive le lien vers la racine */
  $("#page_header a span").text("");     /* retire le n° de version */
  $("input").each(function(i, elt){
      elt=$(elt);
      if (elt.val() == "À changer"){
	  elt.val("");
	  elt.attr("placeholder","À changer");
      }
  });
  var classe = $("#id_classe")
  if(classe.find("option:selected").text().startsWith("PAS_DE_CLASSE")) {
      classe.val("");
  }
  var a_verifier = $("#id_a_verifier");
  a_verifier.parents("tr").hide();
  if (a_verifier.val()=="True"){
      var classes_passees = $("#id_classes_passees");
      classes_passees.parents("tr").hide();
      var no_caution = $("#id_no_caution");
      no_caution.parents("tr").hide();
  }
</script>
{% endblock %}
