
article {
    margin: 3rem 0;
}

a {
    text-decoration: none;
}

img {
    max-width: 100%;
    display: block;
    margin: 0 auto;
}

blockquote {
    width: 65%;
    display: block;
    margin: 1rem auto;
    color: rgba(0,0,0,.5);
    font-size: 1.6rem;
    font-style: italic;
}

blockquote .attribution {
    font-style: normal;
    font-size: 1rem;
    margin-bottom: 1.84rem;
}

hr {
    width: 50%;
    height: 0;
    border: 0;
    border-top: 1px solid rgba(0,0,0,.3);
    margin: 2em auto;
}
