{% load i18n %}
{% load static %}
<h4>{% blocktrans with id=ident%}Recherche pour le livre n° {{id}}{% endblocktrans %}</h4>
{% if found %}
<div class="desc_livre">
  <ul>
    <li class="titre"><b>{{found.materiel.titre}}</b> ({{found.materiel.discipline.libelle}} {{found.materiel.niveau.libelle}} {{found.materiel.Serie}} {{found.materiel.Serie}}) {{found.materiel.editeur}} ({{found.materiel.Annee_Depot_Legal}}, ISBN = <b>{{found.materiel.ISBN}}</b>)</li>
    <li class="editeur">
      {% blocktrans with fp=found.materiel.float_prix|floatformat:2 %}
      prix initial : {{fp}}
      {% endblocktrans %}
      {% translate " € ; tarif aujourd'hui :" %}
      {{found.tarif|floatformat:2}} €
    </li>
    {% if flashes %}
    {% for date, obj, type in flashes %}
    {% if type == "prete" %}
    <li>{% blocktranslate with e=obj.eleve.NomPrenomEleve s=obj.eleve.Lib_Structure d=date|date:'d/m/Y' %}
      Prêté à {{e}} ({{s}}), le {{d}}
      {% endblocktranslate %}
    </li>
    {% else %}
    {% if type == "retour" %}
    <li>{% blocktranslate with e=obj.eleve.NomPrenomEleve s=obj.eleve.Lib_Structure d=date|date:'d/m/Y' %}
      Rendu pour {{e}} ({{s}}), le {{d}}
      {% endblocktranslate %}
    </li>
    {% else %} {# alors type == "revue" #}
    <li>{% blocktranslate with d=obj.date|date:'d/m/Y' %}Flashé dans le stock, le {{d}}{% endblocktranslate %}</li>
    {% endif %}
    {% endif %}
    {% endfor %}
    {% else %}
    <li>{% translate "non prêté, non flashé" %}</li>
    {% endif %}
    {% if found.Perdu %}
    <li class="livre-perdu">
      {% translate "Ce livre a été déclaré perdu" %}
      <button onclick='livre_retrouve(this)'
	      data-id="{{ found.id }}"
	      data-msg='{% translate "Je confirme que le livre est bien retrouvé" %}'>
	{% translate "Retrouvé ?" %}
      </button>
    </li>
    {% endif %}
  </ul>
  <p>
    <ul>
      <li>
	<button onclick="location='/une_etiquette/{{ found.id }}'">
	  <img src="{% static '/img/etiquette-mini.png' %}"
	       alt="étiquette à code-barre"
	       style="width: 25px;"/>
	</button>
	 {% translate "étiquette à code-barres de ce livre" %}
      </li>
      <li>
	{% if found.est_au_pilon %}
	{% blocktranslate with d=found.pilon %}CE LIVRES A ÉTÉ MIS AU PILON, le {{ d }} !{% endblocktranslate %}
	{% else %}
	<button onclick="au_pilon({{ ident }})">
	  <img src="{% static '/img/window-close.svg' %}"
	       alt="mettre au pilon" title="{% translate 'mettre au pilon' %}"
	       style="width: 25px;"/>
	</button>
	{% translate "mettre au pilon ce livre" %}
	{% endif %}
      </li>
    </ul>
  </p>
</div>
{% else %}
<p class = "error">{% translate "Ce numéro de livre n'est pas dans l'inventaire" %}</p>
{% endif %}
