{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<div class="fond-blanc">
 {% if not user.is_authenticated %}
 <div class="login-form">
  <h3>
   {% translate "Authentification" %}
  </h3>
  <form action="/admin/login/?next=/apropos" id="login-form" method="post">
   {% csrf_token %}
   <div class="form-row">
    <label class="required" for="id_username">
     {% translate "Nom d’utilisateur :" %}
    </label>
    <input autocapitalize="none" autocomplete="username"
	   autofocus="" id="id_username" maxlength="150"
	   name="username" required="" type="text"/>
   </div>
   <div class="form-row">
    <label class="required" for="id_password">
     {% translate "Mot de passe :" %}
    </label>
    <input autocomplete="current-password" id="id_password"
	   name="password" required="" type="password"/>
    <input name="next" type="hidden" value="/apropos"/>
   </div>
   <div class="submit-row">
    <input type="submit" value="{% translate 'Connexion' %}"/>
   </div>
  </form>
 </div>
 {% endif %}
 <img alt="salam : SLM" src="{% static '/img/slm.svg' %}"
      style="width: 150px; float: left; margin-right: 12px;"/>
 <h1>
  {% translate "SLM: School Library Management" %}
 </h1>
 <p>
  {% translate "Ce projet a été démarré en 2023 au lycée Jean Bart de Dunkerque, en France. Les livres scolaires y sont gérés par une association, la « coopérative du lycée », animée par des bénévoles. Les élèves sont environ mille cinq cents à bénéficier de la location des livres gérés par la coopérative ; tous ces « clients » passent en moins d’une semaine, pour retirer leurs livres au début d’une année scolaire, et reviennent en fin d’année rendre les livres qu’ils avaient loué." %}
 </p>
 <p>
  {% translate "Pour nommer le projet SLM, on peut le prononcer « Salaam » (سَّلَام), « Shalom » (שָׁלוֹם), ce qui se traduit tout simplement par « salut », mais signifie aussi bien « paix »." %}
 </p>
 <h2>
  {% translate "Licence" %}
 </h2>
 <p>
  {% translate "SLM est soumis à un copyright (analogue d'un droit d'auteur) :" %}
  <br/>
  {% translate "© 2023-2024 Georges Khaznadar &lt;georgesk@debian.org&gt;" %}
 </p>
 <p>
  {% translate "Il est distribué sous la licence" %}
  <a href="https://www.gnu.org/licenses/gpl-3.0.fr.html">
   {% translate "GPL version 3" %}
  </a>
  {% translate ", ce qui signifie que vous pouvez utiliser librement SLM, le copier pour le distribuer ou le vendre, étudier son fonctionnement grâce aux fichiers source maintenus sur le dépôt" %}
  <a href="https://forge.apps.education.fr/georgesk/slm">
   apps.education.fr
  </a>
  {% translate ", le modifier et distribuer ou vendre les version modifiées, mais vous n'avez pas le droit de refuser ces droits à d'autres que vous." %}
 </p>
 <a href="https://openacademie.fr/gemasco/">
  <img alt="livre - Gemasco" src="{% static '/img/book-gemasco.png' %}" style="width: 150px; float: right; margin-left: 12px;"/>
 </a>
 <h2 id="bref-historique">
  {% translate "Bref historique" %}
 </h2>
 <p>
  <b>
   {% translate "SLM" %}
  </b>
  {% translate "a été inspiré par" %}
  <b>
   <a href="https://openacademie.fr/gemasco/">
    {% translate "GemaSCO" %}
   </a>
  </b>
  {% translate ", le logiciel de gestion des manuels scolaires développé par l’organisation" %}
  <a href="https://openacademie.fr/">
   {% translate "OpenAcademie" %}
  </a>
  {% translate ", distribué  sous la licence libre" %}
  <a href="https://fr.wikipedia.org/wiki/Licence_publique_de_l%27Union_europ%C3%A9enne">
   {% translate "EUPL" %}
  </a>
  {% translate "." %}
 </p>
 <p>
  {% translate "En 2023, le logiciel GemaSCO est utilisé par plus de 300 établissements, rend service à plus de cent mille élèves, et permet de gérer près d'un million de manuels scolaires." %}
 </p>
 <p>
  {% translate "SLM utilise la bibliothèque Python Django, ce qui permet de définir des modèles de données basés sur les mêmes structures de tables que GemaSCO met en œuvre." %}
 </p>
 <p>
  {% translate "SLM est une application web, qui est prévue pour fonctionner avec un serveur de puissance modeste, et fonctionne d'emblée avec plusieurs postes clients pour les transactions. La base de données consiste en un fichier unique : base de donnée SQLite3." %}
 </p>
 <p class="bandeau-images">
  <img alt="système Django" src="{% static '/img/logo-django.svg' %}">
   <img alt="Python" src="{% static '/img/python-logo-generic.svg' %}">
    <img alt="SQLite3" src="{% static '/img/sqlite370_banner.gif' %}"/>
    <img alt="jQuery" src="{% static '/img/logo-jquery.png' %}"/>
    <img alt="jQuery-UI" src="{% static '/img/logo-jquery-ui.png' %}"/>
    <img alt="pelican" src="{% static '/img/logo-pelican.svg' %}"/>
    <img alt="GPLv3" src="{% static '/img/GPLv3_Logo.svg' %}">
     <img alt="EUPL" src="{% static '/img/Logo_EUPL.svg' %}"/>
    </img>
   </img>
  </img>
 </p>
</div>
{% endblock %}

