{% load i18n %}
{# rs est une instance de RevueStock, perdu est un booleen #}
{% if not existe %}
{% if pilon %}
<h1>{% translate "Ce livre a été mis au pilon !" %}</h1>
{% else %}
<h1>{% translate "Ce code est inconnu !" %}</h1>
{% endif %}
{% else %}
<ul>
  <li>{{ rs.code.materiel.titre }}</li>
  {% if rs.prete %}
  <li>{% blocktranslate with d=rs.dernier_pret.date_pret e=rs.dernier_pret.eleve %}Prêté, le {{ d }} à {{ e }}{% endblocktranslate %}</li>
  {% if perdu %}
  <li><b>{% translate "Le livre était perdu !" %}</b></li>
  {% endif %}
  {% else %}
  <li>{% translate "en stock 😁" %}</li>  
  {% endif %}
</ul>
{% endif %}
