{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Impression du code-barre pour « " %}{{ manuel.titre }}{% translate " » (numéro" %} {{ numero }}{% translate ")" %}
</h1>
<button id="inventaire" onclick="location ='/inventaire'" style="margin:5px 0;">
 {% translate "⏮ Retour à l'Inventaire" %}
</button>
<br/>
<p class="tableau-etiquettes">
 {% for l in etiquettes_ligs %}
  {% for c in etiquettes_cols %}
 <button class="une-etiquette" onclick="location='/une_etiquette_go/{{ numero }}/{{ l }}/{{ c }}'" title="{% translate 'Cliquez ici pour créer le document PDF' %}">
  {% translate "Étiquette ici ?" %}
 </button>
 {% endfor %}
 <br>
  {% endfor %}
 </br>
</p>
{% endblock %}

