{% load i18n %}
<div class="livre">
 <div class="container{% if l.tronc %} fixe{% endif %}">
   <span class="info">
     {% if l.tronc %}
     <span class="abrege" data-abg="{{ l.abg }}"
	   title="{{ l.titre }}{% translate ' (TRONC COMMUN)' %}">
       {{ l.abrege }}
     </span>
     {% else %}
     {% if l.abrege == 'poche' %}
     <span class="abrege" data-abg="{{ l.abrege }}"
	   title="{{ l.titre }}{% translate ' (Livre de poche)' %}">
       {% translate 'Livre de poche :' %} {{ l.titre }}
     </span>
     {% else %}
     <span class="abrege" data-abg="{{ l.abg }}"
	   title="{{ l.titre }}{% translate ' (LV2/OPTION/SPÉ)' %}">
       {{ l.abrege }}
     </span>
     {% endif %}
     {% endif %}
     <span class="ids">
       {{ l.ids }}
     </span>
   </span>
 </div>
</div>

