{% load i18n %}
<h2>
 {% translate "Manuels de" %} {{debut1}} {% translate "à" %} {{fin}} {% translate "sur un total de" %} {{nb_manuels_en_pret}}
</h2>
{% if fin < nb_manuels_en_pret %}
<button onclick="enVoirPlus()">
 {% translate "En voir" %} {{MAX}} {% translate "de plus ..." %}
</button>
{% endif %}
<div class="flexcontainer" data_fin="{{fin}}" id="les_manuels">
 {% for m in manuels_en_pret %}
 <div class="flexmini">
  <p title="{% blocktranslate with t=m.inventaire.materiel.titre e=m.eleve.NomPrenomEleve d=m.date_pret %}{{t}}, prêté à {{e}} le {{d}}{% endblocktranslate %}">
   {{m.inventaire.id}}
  </p>
 </div>
 {% endfor %}
</div>

