{% load i18n %}
<h1>
 {% translate "Classe :" %} {{classe}}{% translate " ; liste des élèves (" %}{{eleves | length}}{% translate ")" %}
</h1>
<div class="flexcontainer">
 {% for e in eleves %}
 <div class="flexmoyen">
  <p>
   {{e.NomPrenomEleve}}
  </p>
 </div>
 {% endfor %}
</div>

