{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Impression des versos de cartes de membres" %}
</h1>
<div style="width: 500px; display: inline-block;">
 <form method="post">
  {% csrf_token %}
  <fieldset>
   <label for="nb">
    {% translate "Nombre de pages à imprimer : " %}
   </label>
   <input id="nb" name="nb" type="text" value="{{ nb }}"/>
   <br/>
   <input type="submit" value="{% translate 'Mettre à jour' %}"/>
   <br/>
   <p>
    {% translate "Sur" %} {{ nb }} {% translate "page" %}{% if nb > 1 %}{% translate "s" %}{% endif%}{% translate ", on imprimera" %} {{ cartes }} {% translate "versos de cartes de membre." %}
   </p>
  </fieldset>
 </form>
</div>
<button class="actionbuttons" id="printButton" onclick="cartes_membres_print_verso_go()" style="vertical-align: top; display: inline-block;">
 <img alt="Créer le fichier PDF" src="{% static '/img/document-print.svg' %}" title="{% translate 'Créer le fichier PDF' %}"/>
</button>
<!-- formulaire caché pour lancer l'impression -->
<form action="/cartes_membres_print_verso_go" id="go" method="post" style="display: none;">
 {% csrf_token %}
 <input name="nb" type="text" value="{{ nb }}"/>
</form>
<script>
 function cartes_membres_print_verso_go(){
      var f = $("#go");
      f.submit();
  }
</script>
{% endblock %}

