{% load i18n %}
{% load static %}
<p>
 {% translate "À la date du" %} {{ date }}{% translate ", il y a" %} {{ nb }} {% translate "étiquettes à imprimer, sur" %}
  {{ pages }} {% translate "pages. Voici une prévisualisation de la première page." %}
</p>
<p class="message_preview">
 {% translate "On peut" %}
 <b>
  {% translate "cliquer sur certaines zones" %}
 </b>
 {% translate "pour y imprimer une étiquette," %}
 <br/>
 {% translate "ou pas. Cliquez sur le" %}
 <b>
  {% translate "bouton de rafraîchissement" %}
 </b>
 {% translate "de la prévisualisation," %}
 <br/>
 {% translate "en haut à gauche, pour valider toute nouvelle disposition des" %}
 <br/>
 {% translate "étiquettes sur la première page." %}
 <br/>
 <b>
  {% translate "N. B. :" %}
 </b>
 {% translate "le compte des nouveaux manuels n'est pris en compte" %}
 <br/>
 {% translate "à l'inventaire que quand on a fini de générer le fichier PDF." %}
</p>

