{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<fieldset class="fond-blanc">
 <legend>
  {% translate "Constantes de l'établissement" %}
 </legend>
 <table class="tableau-donnees" id="tab-constantes">
  <tr>
   <th>
    {% translate "Action" %}
   </th>
   <th>
    {% translate "Nom de l'établissement" %}
   </th>
   <th>
    {% translate "Code RNE" %}
   </th>
   <th>
    {% translate "Année scolaire" %}
   </th>
   <th>
    {% translate "Chef d'établissement" %}
   </th>
   <th>
    {% translate "Intendant" %}
   </th>
  </tr>
  {% for c in constantes %}
  <tr>
   <td>
    <button onclick="delConstante({{ c.pk }})">
     <img alt="supprimer" src="{% static '/img/edit-delete.svg' %}" title="{% translate 'Supprime l&apos;enregistrement' %}"/>
    </button>
    <button onclick="editConstante({{ c.pk }})">
     <img alt="éditer" src="{% static '/img/gtk-edit.svg' %}" title="{% translate 'Édite et Modifie l&apos;enregistrement' %}"/>
    </button>
    <button onclick="cloneConstante({{ c.pk }})">
     <img alt="cloner" src="{% static '/img/edit-add.svg' %}" title="{% translate 'Crée puis édite un clone de l&apos;enregistrement' %}"/>
    </button>
   </td>
   <td>
    {{ c.NomEts }}
   </td>
   <td>
    {{ c.CodeRNE }}
   </td>
   <td>
    {{ c.AnneeScolaire }}
   </td>
   <td>
    {{ c.Civilite_ChefEts }} {{ c.NomChefEts }} {% translate "(" %}{{ c.Titre_ChefEts }}{% translate ")" %}
   </td>
   <td>
    {{ c.Civilite_AgentComptable }} {{ c.NomAgentComptable }} {% translate "(agent comptable)" %}
   </td>
  </tr>
  {% endfor %}
 </table>
 <button onclick="newConstante({{ c.pk }})">
  <img alt="nouveau" src="{% static '/img/edit-add.svg' %}" style="width: 50px;" title="{% translate 'Crée un nouvel enregistrement à partir de zéro' %}"/>
 </button>
</fieldset>
<fieldset class="fond-blanc">
 <legend>
  {% translate "Messages prédéfinis" %}
 </legend>
 <table class="tableau-donnees" id="tab-messages">
  <tr>
   <th>
    {% translate "Action" %}
   </th>
   <th>
    {% translate "N°" %}
   </th>
   <th>
    {% translate "Prêt élève" %}
   </th>
   <th>
    {% translate "Retour élève" %}
   </th>
   <th>
    {% translate "Prêt professeur" %}
   </th>
   <th>
    {% translate "Retour professeur" %}
   </th>
  </tr>
  {% for m in messages %}
  <tr>
   <td>
    <button onclick="delMessages({{ m.N }})">
     <img alt="supprimer" src="{% static '/img/edit-delete.svg' %}" title="{% translate 'Supprime l&apos;enregistrement' %}"/>
    </button>
    <button onclick="editMessages({{ m.N }})">
     <img alt="éditer" src="{% static '/img/gtk-edit.svg' %}" title="{% translate 'Édite et Modifie l&apos;enregistrement' %}"/>
    </button>
    <button onclick="cloneMessages({{ m.N }})">
     <img alt="cloner" src="{% static '/img/edit-add.svg' %}" title="{% translate 'Crée puis édite un clone de l&apos;enregistrement' %}"/>
    </button>
   </td>
   <td>
    <b>
     {{ m.N }}
    </b>
   </td>
   <td>
    {{ m.Pret_Recommandation|slice:":100" }}{% translate " ..." %}
   </td>
   <td>
    {{ m.Retour_Recommandation|slice:":100" }}{% translate " ..." %}
   </td>
   <td>
    {{ m.Pret_Recom_Prof|slice:":100" }}{% translate " ..." %}
   </td>
   <td>
    {{ m.Retour_Recom_Prof|slice:":100" }}{% translate " ..." %}
   </td>
  </tr>
  {% endfor %}
 </table>
 <button onclick="newMessages({{ m.N }})">
  <img alt="nouveau" src="{% static '/img/edit-add.svg' %}" style="width: 50px;" title="{% translate 'Crée un nouvel enregistrement à partir de zéro' %}"/>
 </button>
</fieldset>
<fieldset class="fond-blanc">
 <legend>
  {% translate "Imprimer les fiches de suivi pour l'année" %} {{ param.AnneeScolaire }}
    {% translate "(dernière année définie dans les" %}
  <i>
   {% translate "constantes" %}
  </i>
  {% translate ")" %}
 </legend>
 <!-- formulaire invisible pour faire imprimer les fiches -->
 <form action="fiches_suivi_print_go" id="go" method="post" style="display: none;">
  {% csrf_token %}
  <input )="" id="classes_input" name="classes" type="text" value=""/>
  <input name="annee" type="text" value="{{ param.AnneeScolaire }}">
  </input>
 </form>
 <table class="tableau_prets" id="tableau_classes">
  <tr>
   <th>
    {% translate "Classe" %}
   </th>
   <th>
    {% translate "Nombre" %}
    <br/>
    {% translate "de fiches" %}
   </th>
   <th>
    {% translate "Imprimer tout" %}
    <br/>
    {% translate "(" %}{{ total }} {% translate "fiches)" %}
    <br/>
    <button onclick="fiches_suivi_print_go()">
     <img alt="imprimer" src="{% static '/img/fiche-suivi-print.svg' %}" style="width: 50px;" title="{% translate 'imprimer les fiches de suivi' %}"/>
    </button>
   </th>
  </tr>
  {% for lib, c in classes.items %}
  <tr>
   <td class="libelle">
    {{ lib }}
   </td>
   <td>
    {{ c }}
   </td>
   <th>
    <button onclick="fiches_suivi_print_go('{{ lib }}')">
      <img alt="imprimer" src="{% static '/img/fiche-suivi-print.svg' %}"
	   style="width: 25px;"
	   title="{% blocktranslate with lib=lib %}imprimer les fiches de suivi pour la classe {{ lib }}{% endblocktranslate %}"/>
    </button>
   </th>
  </tr>
  {% endfor %}
 </table>
</fieldset>
<div id="dialog" style="display: none;">
 {% translate "Êtes-vous sûr de vouloir effacer cet enregistrement ?" %}
</div>
{% endblock %}

