{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Corrélations" %}
</h1>
<p>
 {% translate "Les options de SIÈCLE sont en colonnes, les abrégés de livres en lignes." %}
</p>
<p>
 {% translate "Les fortes corrélations positives sont en" %}
 <span style="background: lightgreen;">
  {% translate "vert" %}
 </span>
 {% translate "." %}
</p>
<div id="correlation">
 <img alt="attendre" src="{% static '/img/timer1.gif' %}" title="{% translate 'attendre' %}"/>
</div>
<p>
 {% translate "En" %}
 <a href="/correlation_code">
  {% translate "cliquant ici" %}
 </a>
 {% translate ", on peut faire calculer en quelques minutes des tableaux pour du code source Python afin de réévaluer les corrélations. La précédente évaluation a été faite le 13 décembre 2023. Les données du tableau ci-dessus peuvent être reprises dans un DataFrame pandas, en utilisant" %}
 <code>
  pd.Dataframe.from_dict()
 </code>
 {% translate "et le code source qui suit." %}
</p>
<div class="python-code" id="python-code" style="display: none;">
</div>
<script>
 correlation_init();
</script>
{% endblock %}

