{% load i18n %}
{% load static %}
<div class="bouton-suppr" data-id="{{ eleve.id }}">
 {{ eleve.NomPrenomEleve }} {% translate "(" %}{{ eleve.Lib_Structure }}{% translate ")" %}
 <button onclick="moins_nomprenom_supplement(this)" title="{% translate 'supprimer cet élève' %}">
  <img alt="supprimer cet élève" src="{% static '/img/edit-delete.svg' %}" title="{% translate 'supprimer cet élève' %}"/>
 </button>
</div>

