{% extends "base.html" %}
{% block title %}{{ article.title | striptags }}{% endblock %}
{% block content %}
<article class="post" itemprop="blogPost" itemscope itemtype="http://schema.org/BlogPosting">
    <header>
        <h1 itemprop="headline" id="{{ article.slug }}">{{ article.title }}</h1>
        <p>
            <meta itemprop="datePublished" content="{{ article.date.isoformat() }}">
            <meta itemprop="dateModified" content="{{ article.date.isoformat() }}">
            {% if GRAVATAR_IMAGE %}
            <meta itemprop="image" content="{{ GRAVATAR_IMAGE }}">
            {% endif %}
            Posted on {{ article.date | strftime('%d %B %Y') }} in <a href="{{ SITEURL }}/{{ article.category.url }}">{{ article.category }}</a>
        </p>
    </header>
    <section id="content" itemprop="mainEntityOfPage">
        {{ article.content }}
    </section>
    <footer>
        {% if article.tags %}
        <div class="tags">
            {% for tag in article.tags %}
                <a href="{{ SITEURL }}/{{ tag.url }}">{{ tag | escape }}</a>
            {% endfor %}
        </div>
        {% endif %}
        {% include "fragments/author.html" %}
    </footer>
</article>
{% endblock %}

