{% load i18n %}
{% load static %}
<!DOCTYPE html>
<html>
 <head>
  <title>
   {% translate "..:: SLM :" %} {{ nom_page }} {% translate "::.." %}
  </title>
  <script src="{% static 'js/jquery/jquery.js' %}">
  </script>
  <script src="{% static 'js/jquery-ui/jquery-ui.js' %}">
  </script>
  <script src="{% static 'js/jquery-ui-touch-punch/jquery.ui.touch-punch.js' %}">
  </script>
  <link href="{% static 'js/jquery-ui/themes/base/all.css' %}" rel="stylesheet"/>
  <link href="{% static 'img/favicon.ico' %}" rel="icon"/>
  <script src="/jsi18n">
  </script>
  <script src="{% static 'js/slm.js' %}">
  </script>
  <meta content="width=device-width" name="viewport"/>
  <link href="{% static 'css/gestion.css' %}" rel="stylesheet"/>
  <link href="{% static 'css/gestion-mobile.css' %}" media="(max-width: 480px)" rel="stylesheet"/>
  <link href="{% static 'css/gestion-tablet.css' %}" media="(max-width: 767px)" rel="stylesheet"/>
 </head>
 <body>
  <div id="contents">
   {% block contents %}
   <!-- contenu de la page -->
   {% endblock %}
  </div>
 </body>
</html>

