{% load i18n %}
<p>
 {% translate "La caution a déjà été rendue, le" %} {{ la_caution.rendue_le|date:'j F Y'}}{% translate "." %}
</p>
<p>
 {% translate "Un chèque de" %} {{ la_caution.somme_rendue|floatformat:2}}{% translate " € a été émis
  ce jour-là." %}
</p>
<fieldset>
 <table>
  <tr>
   <th colspan="2">
    {% translate "Annulation de l'opération précédente" %}
   </th>
  </tr>
  <tr>
   <td>
    {% translate "Je suis sûr(e) de vouloir annuler" %}
   </td>
   <td>
    <input id="ok1" name="ok1" type="checkbox"/>
   </td>
  </tr>
  <tr>
   <td>
    {% translate "Vraiment, je suis sûr(e) de vouloir annuler" %}
   </td>
   <td>
    <input id="ok2" name="ok2" type="checkbox"/>
   </td>
  </tr>
  <tr>
   <th colspan="2">
    {% translate "Commentaires" %}
   </th>
  </tr>
  <tr>
   <td colspan="2">
    <textarea cols="40" id="comment" name="comment" rows="4">{{ la_caution.commentaire }}</textarea>
   </td>
  </tr>
 </table>
 <input id="annule_rendu_numero" name="annule_rendu_numero" type="hidden" value="{{ la_caution.numero }}"/>
</fieldset>

