{% load i18n %}
{% load static %}
<!DOCTYPE html>
<html>
 <head>
  <title>
   {% translate "État des prêts pour la" %} {{ classe }}
  </title>
  <link href="{% static 'css/gestion.css' %}" rel="stylesheet"/>
  <script src="{% static 'js/jquery/jquery.js' %}">
  </script>
  <script src="{% static 'js/jquery-ui/jquery-ui.js' %}">
  </script>
  <link href="{% static 'js/jquery-ui/themes/base/all.css' %}" rel="stylesheet"/>
  <link href="{% static 'img/favicon.ico' %}" rel="icon"/>
  <script src="{% static 'js/slm.js' %}">
  </script>
 </head>
 <body>
  <h1>
   {% translate "État des prêts pour la" %} {{ classe }}
  </h1>
  <p>
   {% translate "Imprimé le :" %} {{ date }}
   <button class="no-print" onclick="print()" style="margin-left: 15px;">
    <img alt="imprimer" src="{% static 'img/document-print.svg' %}"/>
   </button>
  </p>
  {% if eleves %}
  <table class="tableau_prets">
   {% for e, clean in eleves.items %}
   <tr>
    <td>
     {% if clean %}{% translate "☑" %}{% else %}{% translate "☐" %}{% endif %}
    </td>
    <td>
     {{ e.doit }}
    </td>
   </tr>
   {% endfor %}
  </table>
  {% else %}
  <p>
   {% translate "Pas d'élèves à lister" %}
  </p>
  {% endif %}
 </body>
</html>

