@import "_reset.css";
@import "_base.css";
@import "_syntax.css";
@import "_layout.css";
@import "_flex.css";
@import "_typography.css";
@import "_colors.css";

@import "_tables.css";
@import "_buttons.css";
@import "_tags.css";
@import "_circles.css";

@import "_author.css";
