{% load i18n %}
<p>
 {% translate "La somme à rendre est diminuée quand des manuels sont perdus : voir la fiche-mémoire." %}
</p>
<fieldset>
 <table>
  <tr>
   <td>
    {% translate "Somme à rendre :" %}
   </td>
   <td>
    <input id="somme" name="somme" placeholder="{% translate '0,00' %}" type="text" value="{{ a_rendre|floatformat:2 }}"/>
    {% translate " €" %}
   </td>
  </tr>
  {% if no_caution == "0" %}
  <tr>
   <td>
    {% translate "Numéro de caution :" %}
   </td>
   <td>
    <input id="numero_de_la_caution" name="numero" placeholder="{% translate '12345' %}" type="text" value="{{ no_caution }}"/>
   </td>
  </tr>
  {% else %}
  <tr style="display: none;">
   <td>
    {% translate "Numéro de caution :" %}
   </td>
   <td>
    <input id="numero_de_la_caution" name="numero" placeholder="{% translate '12345' %}" type="text" value="{{ no_caution }}"/>
   </td>
  </tr>
  {% endif %}
 </table>
</fieldset>

