.site-header {
    padding: 1rem 1rem;
}

@media screen and (min-width: 54em) {
  .main-content {
    padding: 1rem 1rem;
  }
}

.summary {
    display: inline-block;
    position: fixed;
    top: 5px;
    left: 3px;
    background: yellow;
    border: 1px solid navy;
    font-size: 80%;
    padding: 5px;
    border-radius: 5px;
    max-width: 200px;
    z-index:10;
}

.summary h3{
    font-size: 1em;
    margin: 0.5rem 0 0.2rem 0;
}

nav.menu li{
    list-style-type : none;
    display: inline-block;
    margin: 0 3px;
}

nav.menu li a.active{
    font-weight: 900;
    background: rgba(255,255,0,0.5);
    border: 1px solid navy;
    color: navy;
}

button.gotop {
    float: right;
    position: relative;
    top: 20px;
}

dt {
    font-weight: bolder;
    text-decoration-line: underline;
    text-decoration-thickness: 1.5px;
}

dd {
    padding-left: 3em;
}

img.shadowed {
    border: 1px darkgrey solid;
    filter: drop-shadow(30px 10px 4px #56738f);
    display: inline-block;
    margin-right: 35px;
    vertical-align: middle;
}

.translation-header {
    position: fixed;
    display: inline-block;
    top: 10px;
    right: 10px;
    background: rgba(255, 255, 0, 0.9);
    border: 1px solid black;
    border-radius: 5px;
    padding: 0 5px;
    z-index: 10;
}

.flags {
    display: flex;
    padding: 2px;
}

.flags img {
    margin: 0 2px;
}

ol {
    list-style: numeric;
}
