/* Mobile */

.site-header {
    padding: 2rem 1rem;
    text-align: center;
}

.main-content {
    padding: 2em 1em;
}

.site-footer {
    padding: 2em 1em;
    font-size: 1rem;
}


/* Tablets */

@media screen and (min-width: 42em) and (max-width: 54em) {
    .site-header {
        padding: 3rem 4rem;
    }

    .main-content {
        padding: 2rem 4rem;
    }

    .site-footer {
        padding: 2rem 4rem;
    }

}

/* Desktop */

@media screen and (min-width: 54em) {
    .site-header {
        padding: 5rem 6rem;
    }

    .main-content {
        max-width: 54rem;
        padding: 2rem 6rem;
        margin: 0 auto;
    }

    .site-footer {
        max-width: 54rem;
        padding: 2rem 6rem;
        margin: 0 auto;
    }

}

@media print {
    .site-header {
        padding: .5rem 0rem;
    }
}
