{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<button onclick="RAZmodele({{ names }})" style="float: right">
 {% translate "Tout recommencer" %}
</button>
<h1>
 {% translate "Importation de fichiers CSV depuis GemaSCO" %}
</h1>
<p>
 {% translate "Tirez-glissez les fichiers CSV depuis un gestionnaire de fichiers vers les zones ci-dessous." %}
</p>
<div class="mod_flexcontainer">
 {% for mod, obj in modeles.items %}
 <div class="mod_flex model" data-model="{{ mod }}" data-related="{{ obj.related }}" ondragenter="dragenterCSV(event);" ondragleave="dragleaveCSV(event);" ondrop="dropCSV(event);">
  <button class="petitbouton">
    <img alt="remise à zéro" onclick="RAZmodele('{{ mod }}')"
	 src="{% static '/img/edit-delete.svg' %}"
	 title="{% blocktranslate with mod=mod %}remettre à zéro la table du modèle {{ mod }}{% endblocktranslate %}"/>
  </button>
  <p>
   {% translate "Classe :" %}
   <b>
    {{ mod }}
   </b>
  </p>
  <p>
   {% translate "Fichier :" %}
   <span class="csvfile">
    {{ obj.csvfile }}
   </span>
  </p>
 </div>
 {% endfor %}
</div>
<div id="message" style="display: none">
</div>
<script>
 importeFromGemaSCO_init();
</script>
{% endblock %}

