{% extends 'gestion/base.html' %}
{% load i18n %}


{% block contents %}
<h1>
  {% translate "Nombre de membres de la coopérative :" %}
  {{ nb_membres }}{% translate ", en date du" %} {{ ladate }}
</h1>
<p>
 {% translate "Sont comptés comme membres de la coopérative tous les élèves qui ont au moins un livre prêté." %}
</p>
<p>
 <b>
  {% translate "Il y a quelques sources d'erreurs :" %}
 </b>
 {% translate "par exemple certains élèves ont un livre prêté, mais c'est juste un livre non rendu (souvent perdu), qui n'est pas encore considéré comme définitvement perdu." %}
</p>
<h1>
 {% translate "Histogramme des livres prêtés" %}
</h1>
<div>
 {{ histogramme_lpe }}
</div>
<h1>
 {% translate "Flux des prêts de manuels" %}
</h1>
<div>
 {{ graphique_prets }}
</div>
<h1>
 {% translate "Flux des retours de manuels" %}
</h1>
<div>
 {{ graphique_retours }}
</div>
<h1>
 {% translate "Liste des classes (nombre d'élèves, proportion de membres)" %}
</h1>
<div class="flexcontainer">
 {% for c in classes %}
 <div class="flexmini medium">
   <p class="simple_link" onclick="showClasse('{{c.libelle}}');"
      title="{% blocktranslate with l=c.libelle %}Cliquer pour plus de détail au sujet de {{l}}.{% endblocktranslate %}">
   {{c.libelle}}
   <br/>
   <span style="font-size: 70%">
     {% translate "(" %}{{c.compte}} {% translate "élèves," %}
     {{ c.membres_pc }} {% translate "% membres)" %}
   </span>
  </p>
 </div>
 {% endfor %}
 <div id="la_classe" style="display: none;">
 </div>
</div>
<h1>
 {% translate "Manuels prêtés" %}
</h1>
<form>
 <fieldset>
  <legend>
   {% translate "Choix de critères" %}
  </legend>
  <label for="cat_manuel">
   {% translate "Titre du manuel" %}
  </label>
  <select id="cat_manuel" name="cat_manuel">
   <option value="0">
    {% translate "-- ne pas filtrer --" %}
   </option>
   {% for mc in manuel_catalogue %}
   <option value="{{mc.id}}">
    {{mc.titre}}
   </option>
   {% endfor %}
  </select>
 </fieldset>
 <input id="debut" name="debut" type="hidden" value="0"/>
</form>
<div id="liste_manuels">
</div>
<h1>
 {% translate "Statistiques des manuels" %}
</h1>
<ul>
 <table class="tableau-donnees">
  <tr style="background: gold;">
   <th>
    {% translate "Niveau + filière" %}
   </th>
   <th>
    {% translate "Volume en m" %}
    <sup>
     {% translate "3" %}
    </sup>
   </th>
   <th>
    {% translate "Masse en kg" %}
   </th>
   <th>
    {% translate "Titres" %}
   </th>
  </tr>
  {% for k, glob in volumes.items %}
    {% if glob.volume > 0 %}
  <tr>
   <th>
    {{ k }}
   </th>
   <td>
    {{ glob.volume|floatformat:3 }}
   </td>
   <td>
    {{ glob.masse|floatformat:0 }}
   </td>
   <td class="overflowing-cell" title="{{ glob.les_titres }}">
    {{ glob.les_titres }}
   </td>
   {% endif %}
      {% endfor %}
   <tr style="background: gold;">
    <th>
     {% translate "Total" %}
    </th>
    <td>
     {{ total.volume|floatformat:0 }} {% translate "m" %}
     <sup>
      {% translate "3" %}
     </sup>
    </td>
    <td>
     {{ total.masse|floatformat:0 }} {% translate "kg" %}
    </td>
    <td class="overflowing-cell" title="{{ total.les_titres }}">
     {{ total.les_titres }}
    </td>
   </tr>
  </tr>
 </table>
</ul>
<script>
 stats_init();
</script>
{% endblock %}

