{% load i18n %}
{% load static %}
<div class="bouton-suppr" data-id="{{ livre.id }}">
 {{livre}}
 <button onclick="moins_livre_supplement(this)" title="{% translate 'supprimer ce livre' %}">
  <img alt="supprimer ce livre" src="{% static '/img/edit-delete.svg' %}" title="{% translate 'supprimer ce livre' %}"/>
 </button>
</div>

