{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<!--
    conteneur pour des chaînes à traduire pour la fonction JS AfficheurDeleves
  -->
<div style="display:none;" id="ade"
     data-nompretes="{% translate '{e} ({p} prêts)' %}"
     data-savoirplus="{% translate 'En savoir plus...' %}"
     ></div>
<div class="fond-blanc">
 <div class="inline400" id="a_qui_ce_livre">
  <h3>
   {% translate "À qui est ce livre ?" %}
  </h3>
  <a href="/revue_du_stock">
   {% translate "revue du stock" %}
  </a>
  <form>
   <label for="idlivre">
    {% translate "Numéro du livre :" %}
   </label>
   <input id="idlivre" name="idlivre" placeholder="{% translate '00000' %}" type="text"/>
  </form>
  <div id="donnees_livre">
  </div>
 </div>
 <div class="inline400" id="etat_classe">
  <h3>
   {% translate "État par classe : livres dus, par élève" %}
  </h3>
  {% translate "Choisir une classe" %}
  <select id="etat_classe_select" onchange="etat_classe(this)">
   <option>
    {% translate "--------" %}
   </option>
   {% for c in classes %}
   <option>
    {{ c }}
   </option>
   {% endfor %}
  </select>
  <h3>
   {% translate "Élèves qui doivent des livres" %}
  </h3>
  <table class="rose">
   <tr>
    <th>
     {% translate "Quatre livres ou plus :" %}
    </th>
    <td>
     <a class="button" href="/eleves_plus_n/secondes/4" target="blank">
      {% translate "Secondes" %}
     </a>
    </td>
    <td>
     <a class="button" href="/eleves_plus_n/premieres/4" target="blank">
      {% translate "Premières" %}
     </a>
    </td>
    <td>
     <a class="button" href="/eleves_plus_n/terminales/4" target="blank">
      {% translate "Terminales" %}
     </a>
    </td>
   </tr>
   <tr>
    <th>
     {% translate "Un livre ou plus :" %}
    </th>
    <td>
     <a class="button" href="/eleves_plus_n/secondes/1" target="blank">
      {% translate "Secondes" %}
     </a>
    </td>
    <td>
     <a class="button" href="/eleves_plus_n/premieres/1" target="blank">
      {% translate "Premières" %}
     </a>
    </td>
    <td>
     <a class="button" href="/eleves_plus_n/terminales/1" target="blank">
      {% translate "Terminales" %}
     </a>
    </td>
   </tr>
  </table>
  <form action="/print_etat_classe" id="classe-form" method="post" style="display: none" target="_blank">
   {% csrf_token %}
   <input id="classe-input" name="classe" type="text"/>
  </form>
 </div>
 <div class="inline400" id="livres_niveau_filiere">
  <h3>
   {% translate "Listes de livres prévisibles" %}
  </h3>
  <form action="livres_pour" method="post" target="_blank">
   {% csrf_token %}
   <table>
    <tr>
     <th style="text-align: right;">
      <label for="niveau">
       {% translate "Catégorie :" %}
      </label>
     </th>
     <td>
      <select id="categorie" name="categorie">
       {% for c in categories %}
       <option>
        {{ c }}
       </option>
       {% endfor %}
      </select>
     </td>
    </tr>
   </table>
   <input type="submit" value="{% translate 'Voir les livres' %}"/>
  </form>
 </div>
</div>
<div class="fond-blanc">
 <div id="accordion">
  <h3>
   {% translate "Livres non prêtés" %}
  </h3>
  <div>
   <form>
    <label for="quelsLivres">
     {% translate "Préciser les livres :" %}
    </label>
    <input id="quelsLivres" name="quelsLivres" placeholder="{% translate 'N&apos;importe quel titre ...' %}" style="width: 500px;" type="text"/>
   </form>
   <p>
    {% translate "affichage progressif ..." %}
    <span id="nb-affiches">
     {% translate "0" %}
    </span>
    {% translate "/" %}
    <span id="nb-total">
     {% translate "total" %}
    </span>
   </p>
   <div class="liste-livres" id="livres-non-pretes" title="{% translate 'Livres prêtés' %}">
    <div class="flexcontainer" id="en-stock">
    </div>
    <div class="timericon" style="display: none;">
     <img alt="By Andrikkos - Own work, CC0, https://commons.wikimedia.org/w/index.php?curid=33919822" src="{% static '/img/timer1.gif' %}" style="margin: 0 auto; width: 150px;"/>
    </div>
   </div>
  </div>
  <h3>
   {% translate "Livres prêtés à quelqu'un" %}
  </h3>
  <div>
   <form>
    <label for="quelsLivresPretes">
     {% translate "Préciser les livres :" %}
    </label>
    <input id="quelsLivresPretes" name="quelsLivresPretes" placeholder="{% translate 'N&apos;importe quel titre ...' %}" style="width: 500px;" type="text"/>
   </form>
   <p>
    {% translate "affichage progressif ..." %}
    <span id="nb-pretes-affiches">
     {% translate "0" %}
    </span>
    {% translate "/" %}
    <span id="nb-pretes-total">
     {% translate "total" %}
    </span>
   </p>
   <div class="liste-livres" id="livres-pretes" title="{% translate 'Livres prêtés' %}">
    <div class="flexcontainer" id="en-pret">
    </div>
    <div class="timericon" style="display: none;">
     <img alt="By Andrikkos - Own work, CC0, https://commons.wikimedia.org/w/index.php?curid=33919822" src="{% static '/img/timer1.gif' %}" style="margin: 0 auto; width: 150px;"/>
    </div>
   </div>
  </div>
  <h3>
   {% translate "Élèves avec au moins un livre prêté" %}
  </h3>
  <div>
   <div class="flexcontainer">
    <div style="width: 400px">
     <form>
      <label for="classe_pretes">
       {% translate "Précisez une classe :" %}
      </label>
      <input id="classe_pretes" name="classe_pretes" placeholder="{% translate 'nom de classe' %}" type="text"/>
     </form>
     <p>
      {% translate "affichage progressif ..." %}
      <span id="eleves-pretes-affiches">
       {% translate "0" %}
      </span>
      {% translate "/" %}
      <span id="eleves-pretes-total">
       {% translate "total" %}
      </span>
     </p>
    </div>
    <button onclick="print_eleves_avec_livres()">
     <img alt="Imprimer la liste des élèves avec livres" src="{% static '/img/document-print.svg' %}" title="{% translate 'Export à un format imprimable' %}"/>
    </button>
   </div>
   <div class="liste-eleves-prets" id="eleves-pretes" title="{% translate 'élèves avec au moins un livre prêté' %}">
    <div class="flexcontainer eleves" id="el-prets">
    </div>
    <div class="timericon" style="display: none;">
     <img alt="By Andrikkos - Own work, CC0, https://commons.wikimedia.org/w/index.php?curid=33919822" src="{% static '/img/timer1.gif' %}" style="margin: 0 auto; width: 150px;"/>
    </div>
   </div>
  </div>
  <h3>
   {% translate "Élèves sans aucun livre prêté" %}
  </h3>
  <div>
   <div class="flexcontainer">
    <div style="width: 400px">
     <form>
      <label for="classe_pretes">
       {% translate "Précisez une classe :" %}
      </label>
      <input id="classe_sans_prets" name="classe_sans_prets" placeholder="{% translate 'nom de classe' %}" type="text"/>
     </form>
     <p>
      {% translate "affichage progressif ..." %}
      <span id="eleves-sans-prets-affiches">
       {% translate "0" %}
      </span>
      {% translate "/" %}
      <span id="eleves-sans-prets-total">
       {% translate "total" %}
      </span>
     </p>
    </div>
    <button onclick="print_eleves_sans_livres()">
     <img alt="Imprimer la liste des élèves sans livres" src="{% static '/img/document-print.svg' %}" title="{% translate 'Export à un format imprimable' %}"/>
    </button>
   </div>
   <div class="liste-eleves-sans-prets" id="eleves-sans-prets" title="{% translate 'élèves avec au moins un livre prêté' %}">
    <div class="flexcontainer eleves" id="el-sans-prets">
    </div>
    <div class="timericon" style="display: none;">
     <img alt="By Andrikkos - Own work, CC0, https://commons.wikimedia.org/w/index.php?curid=33919822" src="{% static '/img/timer1.gif' %}" style="margin: 0 auto; width: 150px;"/>
    </div>
   </div>
  </div>
 </div>
</div>
<div id="message">
</div>
<script>
 inventaire_init()
</script>
{% endblock %}

