{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<img alt="désolé !" src="{% static '/img/desole.svg' %}" style="float: left; height: 100px; margin 0 5px;"/>
<p>
 {% translate "Cette page n'est pas encore implémentée. Peux être dans la version prochaine ?" %}
</p>
{% endblock %}

