{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<form>
 {% csrf_token %}
 <label for="nomprenom">
  {% translate "Prêtés après le :" %}
 </label>
 <input %}="" date1="" endif="" id="date1" if="" name="date1" placeholder="{% translate 'AAAA-mm-jj' %}" type="text" value="{{ date1 }}" {%=""/>
 <label for="nomprenom">
  {% translate "Rendus avant le :" %}
 </label>
 <input %}="" date2="" endif="" id="date2" if="" name="date2" placeholder="{% translate 'AAAA-mm-jj' %}" type="text" value="{{ date2 }}" {%=""/>
</form>
<p>
 <button class="actionbuttons" onclick="purger_prets_go()">
  <img alt="Purger les enregistrements" src="{% static '/img/edit-delete.svg' %}" title="{% translate 'Purge les enregistrements' %}"/>
 </button>
 {% translate "Affichage progressif :" %}
 <span id="numero">
  {% translate "0" %}
 </span>
 {% translate "/" %}
 <span id="total">
  {% translate "0" %}
 </span>
</p>
<div class="liste-livres" id="scrollable">
 <table class="tableau-donnees" id="table-retours">
  <tr>
   <th>
    {% translate "Prêté le" %}
   </th>
   <th>
    {% translate "Rendu le" %}
   </th>
   <th>
    {% translate "À" %}
   </th>
   <th>
    {% translate "Titre" %}
   </th>
  </tr>
 </table>
 <div class="timericon" style="display: none;">
  <img alt="By Andrikkos - Own work, CC0, https://commons.wikimedia.org/w/index.php?curid=33919822" src="{% static '/img/timer1.gif' %}" style="margin: 0 auto; width: 150px;"/>
 </div>
</div>
<div id="message" style="display: none;">
 <p>
  {% translate "Vérifiez bien les dates : si elles ne sont pas indéfinies, alors leur format doit être « aaaa-mm-dd » ; notez bien que l'année est sur quatre chiffres (aaaa). D'autre part les dates ne doivent pas être fantaisistes." %}
 </p>
</div>
<div id="message-suppression" style="display: none;">
 <p>
  {% translate "Vous êtes sur le point de supprimer" %}
  <span id="count">
   {% translate "nombre" %}
  </span>
  {% translate "enregistrements de prêt et rendu d'un livre." %}
 </p>
 <p>
  {% translate "Cette suppression est définitive ; avez-vous pensé à faire une     sauvegarde de la base de donnée avant cela, ou est-ce sans importance ?" %}
 </p>
</div>
<script>
 purger_prets_init();
</script>
{% endblock %}

