{% extends 'gestion/base.html' %}
{% load i18n %}

{% block contents %}
<div class="flexcontainer">
 <div class="flexcontained">
  <a class="title" href="eleves">
   {% translate "Base élèves" %}
  </a>
  <ul>
   <li>
    {% translate "Individuellement ou par classe" %}
   </li>
   <li>
    {% translate "Inscription provisoire d'un élève" %}
   </li>
   <li>
    {% translate "Impression du cahier de cautions" %}
   </li>
   <li>
    {% translate "Impression des listes d'élèves" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="cartes">
   {% translate "Cartes de membre" %}
  </a>
  <ul>
   <li>
    {% translate "Pour tout un groupe de classe" %}
   </li>
  </ul>
  {% translate "Pour une seule carte de membre : voir « Base élèves »" %}
 </div>
 <div class="flexcontained">
  <a class="title" href="/prof_livre_invite">
   {% translate "Livres particuliers" %}
  </a>
  <ul>
   <li>
    {% translate "Quand un prof veut faire lire un ou plusieurs livres particuliers à quelques élèves." %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="/cautions">
   {% translate "Cautions" %}
  </a>
  <ul>
   <li>
    {% translate "Pour gérer la restitution des cautions quand un élève quitte la coopérative" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="constantes">
   {% translate "Constantes" %}
  </a>
  <ul>
   <li>
    {% translate "Adresse de l'établissement, etc." %}
   </li>
   <li>
    {% translate "Messages prédéfinis pour les imprimés" %}
   </li>
   <li>
    {% translate "Imprimer les fiches de suivi pour l'année" %} {{ param.AnneeScolaire }}
	{% translate "(dernière année définie dans les" %}
    <i>
     {% translate "constantes" %}
    </i>
    {% translate ")" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="purger_prets">
   {% translate "Purger des prêts" %}
  </a>
  <ul>
   <li>
    {% translate "On peut effacer des prêts anciens si les livres sont rendus" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="siecle">
   {% translate "Importer SIECLE" %}
  </a>
  <ul>
   <li>
    {% translate "Se munir d'un fichier CSV, encodé en UTF-8" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="/verif_plan/">
   {% translate "Étagères de livres" %}
  </a>
  <ul>
   <li>
    {% translate "Mise en place et vérification du plan des étagères" %}
   </li>
   <li>
    {% translate "Impression des QR-codes pour le mode « boutique »" %}
   </li>
  </ul>
 </div>
</div>
{% endblock %}

