{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Gestion des cartes de membre créées il y a moins de neuf mois" %}
</h1>
<div id="verso" style="padding: 5px 0;">
 <p>
  {% translate "Aucune classe n'est sélectionnée pour le moment ; le bouton ci-dessous permet d'imprimer les versos des cartes de membre, qui sont indépendants de toute classe et de tout élève." %}
 </p>
 <button onclick="imprime_cartes_verso()">
  <img alt="Imprimer les versos de cartes de membre" src="{% static '/img/document-print.svg' %}" title="{% translate 'Imprime les versos de cartes de membre' %}"/>
 </button>
</div>
<form method="post">
 <fieldset>
  {% csrf_token %}
  <label for="filtrage">
   {% translate "Classes à considérer :" %}
  </label>
  <input id="filtrage" name="filtrage" type="text" value="{{ filtrage }}"/>
  <input type="submit" value="{% translate 'Considérer la nouvelle liste' %}"/>
 </fieldset>
</form>
<p>
 {% translate "Sélectionner des classes : Clic, Contrôle-clic, Tirer-glisser." %}
 <br/>
 <span id="imprimables" style="display: none;">
  <button onclick="imprime_cartes()">
   <img alt="Imprimer les cartes de membre" src="{% static '/img/document-print.svg' %}" title="{% translate 'Imprime les cartes de membre' %}"/>
  </button>
  <span id="total">
   {% translate "0" %}
  </span>
  {% translate "cartes de membre sélectionnées." %}
 </span>
</p>
<ul id="classes">
 {% for c in classes %}
 <li data-n="{{ c.cartes_a_imprimer }}">
  {{ c.libelle }}
 </li>
 {% endfor %}
</ul>
<!-- formulaire caché pour appeler la page /cartes_membres_print -->
<form action="/cartes_membres_print" id="print_form" method="post" style="display:none;">
 {% csrf_token %}
 <input id="classes_chosen" name="classes_chosen" type="text" value=""/>
</form>
<script>
 cartes_init();
</script>
{% endblock %}

