{% extends 'gestion/base.html' %}
{% load i18n %}


{% block contents %}
<div class="flexcontainer">
 <div class="flexcontained">
  <a class="title" href="inventaire">
   {% translate "Inventaire" %}
  </a>
  <ul>
   <li>
    {% translate "À qui est ce livre ?" %}
   </li>
   <li>
    {% translate "Liste des livres" %}
   </li>
   <li>
    {% translate "Livres non prêtés" %}
   </li>
   <li>
    {% translate "Élèves avec avec/sans livre" %}
   </li>
   <li>
    {% translate "État par classe" %}
   </li>
   <li>
    {% translate "Livres par niveau/filière" %}
   </li>
  </ul>
 </div>
 <div class="flexcontained">
  <a class="title" href="catalogue">
   {% translate "Catalogue" %}
  </a>
  <ul>
   <li>
    {% translate "Le catalogue des manuels" %}
   </li>
   <li>
    {% translate "Imprimer la liste" %}
   </li>
   <li>
    {% translate "Créer des codes-barres" %}
   </li>
  </ul>
 </div>
</div>
{% endblock %}

