.circle {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    overflow: hidden;
    text-align: center;
    font-size: 0;
    line-height: 0;
    -webkit-box-shadow: 0px 1px 2px 1px rgba(0,0,0,0.12);
    -moz-box-shadow: 0px 1px 2px 1px rgba(0,0,0,0.12);
    box-shadow: 0px 1px 2px 1px rgba(0,0,0,0.12);
}
