{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h2>
 {% translate "Doublons dans SLM :" %}
 <span id="nb_doublons_SLM">
  {{ liste_doublons_SLM| length }}
 </span>
</h2>
{% if liste_doublons_SLM  %}
<ol>
 {% for nom_prenom, e in liste_doublons_SLM.items %}
 <li class="doublon">
  {{ nom_prenom }} {% translate ":" %}
  <div data-sans-accent="{{ e.sans_accent }}">
  </div>
 </li>
 {% endfor %}
</ol>
<script>
 traiteDoublonSlm()
</script>
{% endif %}
<div class="liste_eleves" id="a_importer">
 <div class="targetSiecle" ondragenter="dragenterSiecle(event)" ondragleave="dragleaveSiecle(event)" ondrop="dropSiecle(event)">
  {% translate "Déposez un fichier Siècle au format CSV" %}
  <br/>
  <strong style="font-size: 200%">
   {% translate "ici" %}
  </strong>
 </div>
 <p id="doublons_siecle" style="display: none;">
  {% translate "Doublons dans SIÈCLE :" %}
  <span id="nb_doublons_siecle">
  </span>
  <span id="liste_doublons_siecle">
  </span>
 </p>
 <h2>
  {% translate "Élèves de SIÈCLE :" %}
  <span id="nb_eleves_siecle">
   {% translate "0" %}
  </span>
 </h2>
 <textarea ncol="100" nrow="20"></textarea>
</div>
<div class="liste_eleves" id="nouveaux">
 <h2>
  {% translate "Élèves nouveaux :" %}
  <span id="nb_nouveaux">
   {% translate "0" %}
  </span>
 </h2>
 <button class="big" id="bouton_nouveaux" onclick="entreeParSiecle(this)" style="display: none;">
  {% translate "Inscrire les nouveaux" %}
 </button>
 <textarea ncol="100" nrow="20"></textarea>
</div>
<div class="liste_eleves" id="sortants">
 <h2>
  {% translate "Élèves sortants :" %}
  <span id="nb_sortants">
   {% translate "0" %}
  </span>
 </h2>
 <button class="big" id="bouton_sortants" onclick="sortieParSiecle(this)" style="display: none;">
  {% translate "Effacer les sortants" %}
  <br>
   {% translate "à jour de prêts" %}
  </br>
 </button>
 <button class="toujoursvisible" id="bouton_print_sortants" onclick="tableauSortantsPasAjour()" style="display: none;">
  <img alt="tableau des sortants pas à jour" src="{% static 'img/document-print.svg' %}" title="{% translate 'Imprimer un tableau des sortants avec encore des prêts à régler' %}"/>
 </button>
 <textarea ncol="100" nrow="20"></textarea>
</div>
<div class="liste_eleves" id="restants">
 <h2>
  {% translate "Élèves restants :" %}
  <span id="nb_restants">
   {% translate "0" %}
  </span>
 </h2>
 <p>
  {% translate "... dont" %}
  <span id="nb_a_modifier_vraiment">
   {% translate "0" %}
  </span>
  {% translate "seraient modifiés par SIÈCLE." %}
 </p>
 <button class="big" id="bouton_restants" onclick="modificationParSiecle(this)" style="display: none;">
  {% translate "Mettre à jour les restants" %}
  <br/>
  {% translate "par rapport à SIÈCLE" %}
 </button>
 <textarea ncol="100" nrow="20"></textarea>
</div>
<div id="message" style="display: none;">
</div>
<script>
 siecle_init();
</script>
{% endblock %}

