{% load i18n %}
<h3 class="dialogtitle">
  {% translate "Livres à préparer pour la classe de" %} {{ classe}}
</h3>
<ol class="liste-livres">
  {% for l in livres %}
  <li class="{% if l.abrege == 'poche' %}poche{% else %}manuel{% endif %}">
    {{ l.titre }}
  </li>
  {% endfor %}
</ol>
