{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<h1>
 {% translate "Invitation à parcourir la Coop en mode « boutique »" %}
</h1>
<a href="{{ url }}">
 {% translate "Limite de validité de ce Qr-Code :" %} {{ jeton.perime }}
</a>
<br style="margin: 0 0 20px;"/>
{{ qrcode|safe }}
<div class="no-print" style="display: inline-block; vertical-align: top;">
 <img onclick="print()" src='{% static "/img/document-print.svg" %}' style="margin: 0 0 0 50px; cursor: pointer; vertical-align: top;"/>
 <br/>
 {% translate "imprimer ce QR-code" %}
 <br/>
 {% translate "d'invitation" %}
</div>
{% endblock %}

