{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<form>
 {% csrf_token %}
 <fieldset>
  <legend>
   {% translate "Nous recherchons ..." %}
  </legend>
  <label for="nomprenom">
   {% translate "Élève :" %}
  </label>
  <input %}="" endif="" id="nomprenom" if="" name="nomprenom" nomprenom="" placeholder="{% translate 'NOM, Prénom' %}" type="text" value="{{ nomprenom }}" {%=""/>
  <label for="classe">
   {% translate "Classe" %}
  </label>
  <input id="classe" name="choix_classe" placeholder="{% translate '...' %}" type="text"/>
 </fieldset>
</form>
<div id="provisoire">
 {% translate "L'élève est depuis peu dans l'établissement ? ..." %}
 <button onclick="location='/invite_inscription_provisoire'" style="cursor: pointer;" title="{% translate 'Invitation pour l\'élève, qui s\'inscrit avec son téléphone' %}">
  {% translate "Inscription provisoire" %}
 </button>
</div>
<div id="donnees">
 <div id="donnees-eleve" style="display:none;">
 </div>
 <div id="donnees-classe" style="display:none;">
 </div>
 <div id="boutons0">
  <button id="cahier-cautions" onclick="location = '/cahier_cautions'">
   <img alt="Cahier des cautions" src="{% static '/img/document-print.svg' %}" title="{% translate 'Voir le cahier des cautions' %}"/>
  </button>
  <button id="listes-eleves" onclick="location = '/listes_eleves'">
   <img alt="Listes des élèves" src="{% static '/img/print-liste-eleves.png' %}" style="width:56px;" title="{% translate 'Listes des élèves' %}"/>
  </button>
  <button id="choix-eleves" onclick="location = '/choix_eleves'">
   <img alt="Listes des élèves" src="{% static '/img/user-accounts.svg' %}" style="width:56px;" title="{% translate 'Sélection d&apos;élèves' %}"/>
  </button>
 </div>
</div>
<script>
 eleves_init();
</script>
{% if saved %}
<script>
 signale_eleve_saved()
</script>
{% endif %}

{% endblock %}

