{% load i18n %}
{% load static %}
<!DOCTYPE html>
<html>
 <head>
  <title>
   {% translate "Liste de livres" %}
  </title>
  <link href="{% static 'css/gestion.css' %}" rel="stylesheet"/>
  <script src="{% static 'js/jquery/jquery.js' %}">
  </script>
  <script src="{% static 'js/jquery-ui/jquery-ui.js' %}">
  </script>
  <link href="{% static 'js/jquery-ui/themes/base/all.css' %}" rel="stylesheet"/>
  <link href="{% static 'img/favicon.ico' %}" rel="icon"/>
  <script src="{% static 'js/slm.js' %}">
  </script>
 </head>
 <body>
  <h1>
   {% translate "Liste de livres pour les" %} {{ categorie }}
  </h1>
  <p>
   <button class="no-print" onclick="print()" style="margin-left: 15px;">
    <img alt="imprimer" src="{% static 'img/document-print.svg' %}"/>
   </button>
  </p>
  {% if livres %}
  <table class="tableau_prets">
   <tr>
    <th>
     {% translate "Matière" %}
    </th>
    <th>
     {% translate "Titre" %}
    </th>
    <th>
     {% translate "Auteurs" %}
    </th>
    <th>
     {% translate "Éditeur" %}
    </th>
    <th>
     {% translate "Annee" %}
    </th>
    <th>
     {% translate "ISBN" %}
    </th>
    <th>
     {% translate "Prix indicatif" %}
    </th>
   </tr>
   {% for l in livres %}
   <tr>
    <td>
     {{ l.discipline }}
    </td>
    <td>
     {{ l.titre }}
    </td>
    <td>
     {{ l.Auteurs }}
    </td>
    <td>
     {{ l.editeur }}
    </td>
    <td>
     {{ l.Annee_Depot_Legal }}
    </td>
    <td>
     {{ l.ISBN }}
    </td>
    <td>
     {{ l.Prix|floatformat:2 }}{% translate " €" %}
    </td>
   </tr>
   {% endfor %}
  </table>
  {% translate "Prix total indicatif :" %} {{ prix_total }}{% translate " €." %}
    {% else %}
  <p>
   {% translate "Pas de livres prévus pour" %} {{ niveau }}{% translate "/" %}{{ filiere }}
  </p>
  {% endif %}
 </body>
</html>

