{% load i18n %}
{% load static %}
{% if cautions|length == 0 %}
<p>
 {{ nomprenom }} {% translate "n'a pas de numéro de caution dans la base de données, mais il en existe probablement un, donné avant la mise en place de ce logiciel." %}
</p>
<fieldset style="border: 1px navy solid; padding: 5px; border-radius: 5px; background: #ffffdd;">
 <legend style="border: 1px navy solid; padding: 5px; border-radius: 40px; background: lightcyan;">
  {% translate "Restaurer l'ancien numéro de caution" %}
 </legend>
 <table>
  <tr>
   <td>
    <label for="numero">
     {% translate "Ancien numéro de caution :" %}
    </label>
   </td>
   <td>
    <input id="no_caution" name="no_caution" placeholder="{% translate '12345' %}" type="text"/>
   </td>
  </tr>
  <tr>
   <td>
    <label for="date">
     {% translate "Date (facultative) :" %}
    </label>
   </td>
   <td>
    <input id="date" name="date" placeholder="{% translate 'AAAA-MM-JJ' %}" type="text"/>
   </td>
  </tr>
 </table>
 <button onclick="ancienne_caution()">
  {% translate "Valider" %}
 </button>
</fieldset>
{% else %}
<h3>
  {% translate "Cautions gérées pour le compte de « " %}
  {{ nomprenom }}{% translate " »" %}
</h3>
{% if not eleve %}
<h4 class="remark">
  {{ nomprenom }}
  {% translate "n'est pas dans la base des élèves, mais en a fait partie plus tôt" %}
</h4>
{% endif %}
<table class="tableau_prets">
 <tr>
  <th>
   {% translate "Caution" %}
  </th>
  <th>
   {% translate "Actions" %}
  </th>
  <th>
   {% translate "Commentaires" %}
  </th>
 </tr>
 {% for c in cautions %}
 <tr>
  <td>
    {{ c }}
    {% if not c.est_valide %}{% translate ", rendu :" %}
    {{ c.somme_rendue|floatformat:2 }}{% translate " €" %}
    {% endif %}
  </td>
  <td>
   {% if c.est_valide and c.somme_payee > 0 %}
   <span id="no_caution" style="display: none;">
    {{ c.numero }}
   </span>
   <button onclick="annule_caution('{{ c.sans_accent }}')">
    <img alt="sans-caution" src="{% static '/img/edit-delete.svg' %}" style="width: 50px;" title="{% translate 'Neutraliser la caution (passer à 0 €)' %}"/>
   </button>
   <button onclick="rend_caution('{{ c.sans_accent }}')">
    <img alt="rendre la caution" src="{% static '/img/undo.svg' %}" style="width: 50px;" title="{% blocktranslate with e=nomprenom %}Rendre cette caution pour {{ e }}{% endblocktranslate %}"/>
   </button>
   {% endif %}
   <button onclick="edite_caution('{{ c.sans_accent }}','{{ c.commentaire_html }}')">
    <img alt="éditer les commentaires" src="{% static '/img/gtk-edit.svg' %}" style="width: 50px;" title="{% translate 'Éditer les commentaires pour cette caution' %}"/>
   </button>
  </td>
  <td>
   {{ c.commentaire_html }}
  </td>
 </tr>
 {% endfor %}
</table>
{% endif %}

