{% extends 'gestion/base.html' %}
{% load i18n %}
{% load static %}

{% block contents %}
<div class="fond-blanc" id="qrcode" style="display: inline-block;">
 {{ svg|safe }}
 <p style="font-size: 50%; text-align: center;">
  <a href="{{ url }}">
   {{ url }}
  </a>
 </p>
 <p style="text-align: center;">
  {% translate "Validité : 30 minutes, jusqu'à" %} {{ fin_validite | date:'H:i'}}
 </p>
</div>
{% if eleves_a_verifier %}
<div class="fond-blanc" id="a_verifier" style="display: inline-block;">
 <h2>
  {% translate "Inscriptions à vérifier" %}
 </h2>
 <ul>
  {% for  e in eleves_a_verifier %}
  <li>
   <form action="/eleves" method="post">
    {% csrf_token %}
    <input name="nomprenom" type="submit" value="{{ e.NomPrenomEleve }}"/>
   </form>
  </li>
  {% endfor %}
 </ul>
</div>
{% endif %}
{% endblock %}

