{% extends 'gestion/base.html' %}
{% load i18n %}


{% block contents %}
<form id="form" method="POST">
 {% csrf_token %}
  {% if not clonage %}
 <input name="numero" type="hidden" value="{{ numero }}"/>
 {% endif %}
 <input id="select-categorie" type="hidden"
	value="{% translate '-- ajouter --' %}"/>
 <table class="deux-colonnes-formulaire">
  {{ form.as_table }}
  <tr>
   <td colspan="2">
    <input name="modif_db" style="width: 100%;" type="submit" value="{% translate 'Enregistrer' %}"/>
   </td>
  </tr>
 </table>
</form>
<script>
 catalogue_modif_init({{ categories|safe }}, {{ options|safe }})
</script>
{% if saved %}
<script>
 signale_catalogue_saved()
</script>
{% endif %}
{% endblock %}

